@@ -597,7 +597,7 @@
 ("keyboard" "klvesnice")
 ("keyboard equivalent" "klvesov zkratka")
 ("keyboard modifiers" "klvesov modifiktory")
-("keyboard shorthand" "klvesov zkratka")
+("keyboard shortcut" "klvesov zkratka")
 ("keymaps" "mapovn klves")
 ("keyword" "klov slovo")
 ("keywords" "klov slova")
@@ -621,7 +621,7 @@
 ("left margin" "lev okraj")
 ("left padding" "lev odskoen")
 ("left prime" "lev rka")
-("left ragged" "zarovnn doleva")
+("left aligned" "zarovnn doleva")
 ("left slanted" "sklonn doleva")
 ("left subscript" "doln index vlevo")
 ("left superscript" "horn index vlevo")
@@ -967,7 +967,7 @@
 ("right border" "prav okraj")
 ("right margin" "prav okraj")
 ("right padding" "odskakovn vpravo")
-("right ragged" "zarovnn doprava")
+("right aligned" "zarovnn doprava")
 ("right subscript" "doln index vpravo")
 ("right superscript" "horn index vpravo")
 ("right surrounding" "prav okol")
