@@ -624,7 +624,7 @@
 ("left margin" "venstre margen")
 ("left padding" "venstre mellemrum")
 ("left prime" "venstre primre")
-("left ragged" "venstrejusteret")
+("left aligned" "venstrejusteret")
 ("left slanted" "venstre skrnende")
 ("left subscript" "indextegn til venstre")
 ("left superscript" "potenstegn til venstre")
@@ -975,7 +975,7 @@
 ("right border" "hjre ramme")
 ("right margin" "hjre margen")
 ("right padding" "hjre mellemrum")
-("right ragged" "hjrejusteret")
+("right aligned" "hjrejusteret")
 ("right subscript" "indextegn til hjre")
 ("right superscript" "potenstegn til hjre")
 ("right surrounding" "hjre nrhed")
