@@ -748,7 +748,7 @@
 ("left margin" "linker rand")
 ("left padding" "ruimte links")
 ("left prime" "linker priem")
-("left ragged" "links")
+("left aligned" "links uitgelijnd")
 ("left slanted" "schuin naar links")
 ("left subscript" "linker index")
 ("left superscript" "linker exponent")
@@ -1108,6 +1108,7 @@
 ("really huge" "echt enorm")
 ("really quit" "wilt u echt ophouden")
 ("really tiny" "werkelijk miniem")
+("recent" "recent")
 ("recover autosave file" "herstel veiligheidsbestand")
 ("red" "rood")
 ("redo" "opnieuw")
@@ -1162,7 +1163,7 @@
 ("right cell padding" "ruimte rechterkant cel")
 ("right margin" "rechter rand")
 ("right padding" "ruimte rechts")
-("right ragged" "rechts")
+("right aligned" "rechts uitgelijnd")
 ("right subscript" "rechter index")
 ("right superscript" "rechter exponent")
 ("right surrounding" "rechter omgeving")
@@ -1472,7 +1473,6 @@
 ("use blackboard bold font" "gebruik schoolbord letters")
 ("use bold font series" "gebruik vette letters")
 ("use calligraphical font" "gebruik kalligrafische letters")
-("use catcode definitions in preamble" "gebruik catcodes in preambule")
 ("use footnote font size" "gebruik erg kleine letters")
 ("use fraktur font" "gebruik Gotische letters")
 ("use huge font size" "gebruik enorm grote letters")
