@@ -609,7 +609,7 @@
 ("left margin" "vasen marginaali")
 ("left padding" "vasen tytt")
 ("left prime" "vasemmanpuoleinen ylpilkku")
-("left ragged" "vasen reuna eptasainen")
+("left aligned" "vasen reuna eptasainen")
 ("left slanted" "vasemmalle kalteva")
 ("left subscript" "vasemmanpuoleinen ylindeksi")
 ("left superscript" "vasemmanpuoleinen alaindeksi")
@@ -947,7 +947,7 @@
 ("right border" "oikea reuna")
 ("right margin" "oikea marginaali")
 ("right padding" "oikea tytt")
-("right ragged" "oikea reuna eptasainen")
+("right aligned" "oikea reuna eptasainen")
 ("right subscript" "oikea alaindeksi")
 ("right superscript" "oikea ylindeksi")
 ("right surrounding" "oikea ymprist")
