@@ -622,7 +622,7 @@
 ("left margin" "margine sinistro")
 ("left padding" "spaziatura sinistra")
 ("left prime" "prima sinistra")
-("left ragged" "allineato a sinistra")
+("left aligned" "allineato a sinistra")
 ("left slanted" "inclinato a sinistra")
 ("left subscript" "pedice a sinistra")
 ("left superscript" "apice a sinistra")
@@ -968,7 +968,7 @@
 ("right border" "bordo destro")
 ("right margin" "margine destro")
 ("right padding" "spaziatura destra")
-("right ragged" "allineato a  destra")
+("right aligned" "allineato a  destra")
 ("right subscript" "pedice a destra")
 ("right superscript" "apice a destra")
 ("right surrounding" "surrounding a destra")
