@@ -605,7 +605,7 @@
 ("keyboard" "klawiatura")
 ("keyboard equivalent" "skrt klawiszowy")
 ("keyboard modifiers" "modyfikatory klawiatury")
-("keyboard shorthand" "skrt klawiszowy")
+("keyboard shortcut" "skrt klawiszowy")
 ("keymaps" "mapa klawiszy")
 ("keyword" "sowo kluczowe")
 ("keywords" "sowa kluczowe")
@@ -629,7 +629,7 @@
 ("left margin" "lewy margines")
 ("left padding" "lewe wypenienie")
 ("left prime" "lewy prime")
-("left ragged" "swobodny z lewej")
+("left aligned" "wyrwnanie do lewej")
 ("left slanted" "pochylony w lewo")
 ("left subscript" "lewy indeks dolny")
 ("left superscript" "lewy indeks grny")
@@ -980,7 +980,7 @@
 ("reset" "skasuj")
 ("resize object" "przeskaluj obiekt")
 ("resized" "przeskalowany")
-("results of the search for" "wyniki wyszukiwania dla")
+("search results for" "wyniki wyszukiwania dla")
 ("return" "powrt")
 ("revert" "przywr")
 ("revert buffer" "przywr bufor")
@@ -989,7 +989,7 @@
 ("right border" "prawy brzeg")
 ("right margin" "prawy margines")
 ("right padding" "prawe wypenienie")
-("right ragged" "swobodny z prawej")
+("right aligned" "wyrwnanie do prawej")
 ("right subscript" "prawy indeks dolny")
 ("right superscript" "prawy indeks grny")
 ("right surrounding" "prawe otoczenie")
