@@ -17,6 +17,7 @@
 ("accept all scripts" "aceptar todos los guiones")
 ("accept no scripts" "no aceptar guiones")
 ("accept script" "aceptar guin")
+("accessed" "acceso")  ; ojo, acceder es intransitivo
 ("acknowledgment" "reconocimiento")
 ("acronym" "acrnimo")
 ("action" "accin")
@@ -647,7 +648,7 @@
 ("left margin" "margen izquierdo")
 ("left padding" "acolchado izquierdo")
 ("left prime" "prima izquierda")
-("left ragged" "alineado a la izquierda")
+("left aligned" "alineado a la izquierda")
 ("left slanted" "inclinada izquierda")
 ("left subscript" "subndice a la izquierda")
 ("left superscript" "superndice a la izquierda")
@@ -830,6 +831,7 @@
 ("odd page header" "cabecera de pgina impar")
 ("odd page margin" "margen de pgina impar")
 ("odd page text" "texto de pgina impar")
+("of" "de")
 ("off" "desactivado")
 ("ok" "vale")
 ("old english" "ingls antiguo")
@@ -966,6 +968,7 @@
 ("proportional typewriter" "de ancho fijo proporcional")
 ("proposition" "proposicin")
 ("query replace" "buscar y reemplazar")
+("question" "pregunta")
 ("quit" "salir")
 ("quotation" "cita (varios prrafos)")
 ("quote" "cita")
@@ -1010,7 +1013,7 @@
 ("right border" "borde derecho")
 ("right margin" "margen derecho")
 ("right padding" "acolchado derecho")
-("right ragged" "alineado a la derecha")
+("right aligned" "alineado a la derecha")
 ("right subscript" "subndice a la derecha")
 ("right superscript" "superndice a la derecha")
 ("right surrounding" "entorno derecho")
@@ -1317,6 +1320,7 @@
 ("vietnamese" "vietnamita")
 ("view" "ver")
 ("visible" "visible")
+("volume" "volumen")
 ("warning" "aviso")
 ("welcome" "bienvenido")
 ("welcome to GNU TeXmacs" "bienvenido a GNU TeXmacs")
