@@ -311,7 +311,7 @@
 ("left" "vnster")
 ("left border" "vnstra begrnsning")
 ("left margin" "vnster kant")
-("left ragged" "kantlinje vnster")
+("left aligned" "vnsterjusterad")
 ("left slanted" "lutat t vnster")
 ("left subscript" "subscript vnster")
 ("left superscript" "superscript vnster")
@@ -513,7 +513,7 @@
 ("right" "hger")
 ("right border" "hgra begrnsning")
 ("right margin" "hger kant")
-("right ragged" "kantlinje hger")
+("right aligned" "hgerjusterad")
 ("right subscript" "subscript hger")
 ("right superscript" "superscript hger")
 ("rigid" "stel")
