@@ -12,7 +12,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (texmacs-module (bibtex abbrv)
-  (:use (bibtex bib-utils)))
+  (:use (bibtex bib-utils) (bibtex plain)))
 
 (bib-define-style "abbrv" "plain")
 
@@ -23,7 +23,7 @@
 		`(concat ,(bib-abbreviate (list-ref x 1) "." `(nbsp))
 			 (nbsp))))
 	 (vv (if (bib-null? (list-ref x 2)) "" `(concat ,(list-ref x 2) (nbsp))))
-	 (ll (if (bib-null? (list-ref x 3)) "" (list-ref x 3)))
+	 (ll (if (bib-null? (list-ref x 3)) "" (bib-purify (list-ref x 3))))
 	 (jj (if (bib-null? (list-ref x 4)) "" `(concat ", " ,(list-ref x 4)))))
     `(concat ,f ,vv ,ll ,jj)))
 
@@ -31,7 +31,8 @@
   (:mode bib-abbrv?)
   (let* ((p (bib-field x "pages")))
     (cond
-     ((equal? 1 (length p)) "")
-     ((equal? 2 (length p)) `(concat "pp. " ,(list-ref p 1)))
-     (else `(concat "pp. " ,(list-ref p 1) "--" ,(list-ref p 2))))))
+      ((bib-null? p) "")
+      ((== (length p) 1) "")
+      ((== (length p) 2) `(concat "pp. " ,(list-ref p 1)))
+      (else `(concat "pp. " ,(list-ref p 1) "--" ,(list-ref p 2))))))
 
