@@ -183,6 +183,7 @@
   (tmstrong (textbf 1))
   (tmem (!group "\\em " 1 "\\/"))
   (tmtt (texttt 1))
+  (tmdate (today))
   (tmname (textsc 1))
   (tmsamp (textsf 1))
   (tmabbr 1)
@@ -204,6 +205,7 @@
 (logic-table latex-texmacs-2%
   (tmhlink (!group "\\color{blue} " 1))
   (tmaction (!group "\\color{blue} " 1))
+  (ontop ("{\\genfrac{}{}{0pt}{}{#1}{#2}}"))
   (subindex (index (!append 1 "!" 2))))
 
 (logic-table latex-texmacs-3%
@@ -562,267 +564,6 @@
   (mkey (!recurse (key (!append "meta-" 1))))
   (hkey (!recurse (key (!append "hyper-" 1)))))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;; Language specific preambles
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-
-(logic-table latex-preamble-language-def%
-  ;; FIXME : unicode export should be conditionnally available for each language
-  ;; FIXME : only the babel option is needed in the table
-  ("bulgarian"
-   "\\usepackage[utf8]{inputenc}\n\\usepackage[bulgarian]{babel}")
-  ("czech" "\\usepackage[czech]{babel}")
-  ("danish" "\\usepackage[danish]{babel}")
-  ("dutch" "\\usepackage[dutch]{babel}")
-  ("finnish" "\\usepackage[finnish]{babel}")
-  ("french" "\\usepackage[french]{babel}")
-  ("german" "\\usepackage[german]{babel}")
-  ("hungarian" "\\usepackage[hungarian]{babel}")
-  ("italian" "\\usepackage[italian]{babel}")
-  ("polish" "\\usepackage[polish]{babel}")
-  ("portuguese" "\\usepackage[portuges]{babel}")
-  ("romanian" "\\usepackage[romanian]{babel}")
-  ("russian" "\\usepackage[utf8]{inputenc}\n\\usepackage[russian]{babel}")
-  ("slovene" "\\usepackage[slovene]{babel}")
-  ("spanish" "\\usepackage[spanish]{babel}")
-  ("swedish" "\\usepackage[swedish]{babel}")
-  ("ukrainian"
-   "\\usepackage[utf8]{inputenc}\n\\usepackage[ukrainian]{babel}"))
-
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;; Catcode tables
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-
-(logic-table corkT1-to-latex-catcodes%
-  ("\x00" "\\`{ }")
-  ("\x01" "\\'{ }")
-  ("\x02" "\\^{ }")
-  ("\x03" "\\~{ }")
-  ("\x04" "\\\"{ }")
-  ("\x05" "\\H{ }")
-  ("\x06" "\\r{ }")
-  ("\x07" "\\v{ }")
-  ("\x08" "\\u{ }")
-  ("\x09" "\\b{ }")
-;  ("\x0A" "\\.{ }") ; newline may still be present in strings!!!
-  ("\x0B" "\\c{ }")
-  ("\x0C" "\\k{ }")
-  ("\x0D" ",")
-  ("\x0E" "{\\guilsinglleft}")
-  ("\x0F" "{\\guilsinglright}")
-  ("\x10" "``")
-  ("\x11" "''")
-  ("\x12" ",,")
-  ("\x13" "<<")
-  ("\x14" ">>")
-  ("\x15" "--")
-  ("\x16" "---")
-  ("\x17" "{}")
-  ("\x18" "{}")
-  ("\x19" "{\\i}")
-  ("\x1A" "{\\j}")
-  ("\x1B" "ff")
-  ("\x1C" "fi")
-  ("\x1D" "fl")
-  ("\x1E" "ffi")
-  ("\x1F" "ffl")
-  ("\x80" "\\u{A}")
-  ("\x81" "\\k{A}")
-  ("\x82" "\\'C")
-  ("\x83" "\\v{C}")
-  ("\x84" "\\v{D}")
-  ("\x85" "\\v{E}")
-  ("\x86" "\\k{E}")
-  ("\x87" "\\u{G}")
-  ("\x88" "\\'L")
-  ("\x89" "\\v{L}")
-  ("\x8A" "{\\L}")
-  ("\x8B" "\\'N")
-  ("\x8C" "\\v{N}")
-  ("\x8D" "{\\NG}")
-  ("\x8E" "\\H{O}")
-  ("\x8F" "\\'R")
-  ("\x90" "\\v{R}")
-  ("\x91" "\\'S")
-  ("\x92" "\\v{S}")
-  ("\x93" "\\c{S}")
-  ("\x94" "\\v{T}")
-  ("\x95" "\\c{T}")
-  ("\x96" "\\H{U}")
-  ("\x97" "\\r{U}")
-  ("\x98" "\\\"Y")
-  ("\x99" "\\'Z")
-  ("\x9A" "\\v{Z}")
-  ("\x9B" "\\.Z")
-  ("\x9C" "IJ")
-  ("\x9D" "\\.I")
-  ("\x9E" "{\\dj}")
-  ("\x9F" "{\\S}")
-  ("\xA0" "\\u{a}")
-  ("\xA1" "\\k{a}")
-  ("\xA2" "\\'c")
-  ("\xA3" "\\v{c}")
-  ("\xA4" "\\v{d}")
-  ("\xA5" "\\v{e}")
-  ("\xA6" "\\k{e}")
-  ("\xA7" "\\u{g}")
-  ("\xA8" "\\'l")
-  ("\xA9" "\\v{l}")
-  ("\xAA" "{\\l}")
-  ("\xAB" "\\'n")
-  ("\xAC" "\\v{n}")
-  ("\xAD" "{\\ng}")
-  ("\xAE" "\\H{o}")
-  ("\xAF" "\\'r")
-  ("\xB0" "\\v{r}")
-  ("\xB1" "\\'s")
-  ("\xB2" "\\v{s}")
-  ("\xB3" "\\c{s}")
-  ("\xB4" "\\v{t}")
-  ("\xB5" "\\c{t}")
-  ("\xB6" "\\H{u}")
-  ("\xB7" "\\r{u}")
-  ("\xB8" "\\\"y")
-  ("\xB9" "\\'z")
-  ("\xBA" "\\v{z}")
-  ("\xBB" "\\.z")
-  ("\xBC" "ij")
-  ("\xBD" "!`")
-  ("\xBE" "?`")
-  ("\xBF" "{\\pounds}")
-  ("\xC0" "\\`A")
-  ("\xC1" "\\'A")
-  ("\xC2" "\\^A")
-  ("\xC3" "\\~A")
-  ("\xC4" "\\\"A")
-  ("\xC5" "{\\AA}")
-  ("\xC6" "{\\AE}")
-  ("\xC7" "\\c{C}")
-  ("\xC8" "\\`E")
-  ("\xC9" "\\'E")
-  ("\xCA" "\\^E")
-  ("\xCB" "\\\"E")
-  ("\xCC" "\\`I")
-  ("\xCD" "\\'I")
-  ("\xCE" "\\^I")
-  ("\xCF" "\\\"I")
-  ("\xD0" "{\\DH}")
-  ("\xD1" "\\~N")
-  ("\xD2" "\\`O")
-  ("\xD3" "\\'O")
-  ("\xD4" "\\^O")
-  ("\xD5" "\\~O")
-  ("\xD6" "\\\"O")
-  ("\xD7" "{\\OE}")
-  ("\xD8" "{\\O}")
-  ("\xD9" "\\`U")
-  ("\xDA" "\\'U")
-  ("\xDB" "\\^U")
-  ("\xDC" "\\\"U")
-  ("\xDD" "\\'Y")
-  ("\xDE" "{\\TH}")
-  ("\xDF" "{\\SS}")
-  ("\xE0" "\\`a")
-  ("\xE1" "\\'a")
-  ("\xE2" "\\^a")
-  ("\xE3" "\\~a")
-  ("\xE4" "\\\"a")
-  ("\xE5" "{\\aa}")
-  ("\xE6" "{\\ae}")
-  ("\xE7" "\\c{c}")
-  ("\xE8" "\\`e")
-  ("\xE9" "\\'e")
-  ("\xEA" "\\^e")
-  ("\xEB" "\\\"e")
-  ("\xEC" "\\`{\\i}")
-  ("\xED" "\\'{\\i}")
-  ("\xEE" "\\^{\\i}")
-  ("\xEF" "\\\"{\\i}")
-  ("\xF0" "{\\dh}")
-  ("\xF1" "\\~n")
-  ("\xF2" "\\`o")
-  ("\xF3" "\\'o")
-  ("\xF4" "\\^o")
-  ("\xF5" "\\~o")
-  ("\xF6" "\\\"o")
-  ("\xF7" "{\\oe}")
-  ("\xF8" "{\\o}")
-  ("\xF9" "\\`u")
-  ("\xFA" "\\'u")
-  ("\xFB" "\\^u")
-  ("\xFC" "\\\"u")
-  ("\xFD" "\\'y")
-  ("\xFE" "{\\th}")
-  ("\xFF" "{\\ss}"))
-
-(logic-table cyrillic-catcodes%
-  ("" "\\CYRA")
-  ("" "\\cyra")
-  ("" "\\CYRB")
-  ("" "\\cyrb")
-  ("" "\\CYRV")
-  ("" "\\cyrv")
-  ("" "\\CYRG")
-  ("" "\\cyrg")
-  ("" "\\CYRD")
-  ("" "\\cyrd")
-  ("" "\\CYRE")
-  ("" "\\cyre")
-  ("" "\\CYRZH")
-  ("" "\\cyrzh")
-  ("" "\\CYRZ")
-  ("" "\\cyrz")
-  ("" "\\CYRI")
-  ("" "\\cyri")
-  ("" "\\CYRISHRT")
-  ("" "\\cyrishrt")
-  ("" "\\CYRK")
-  ("" "\\cyrk")
-  ("" "\\CYRL")
-  ("" "\\cyrl")
-  ("" "\\CYRM")
-  ("" "\\cyrm")
-  ("" "\\CYRN")
-  ("" "\\cyrn")
-  ("" "\\CYRO")
-  ("" "\\cyro")
-  ("" "\\CYRP")
-  ("" "\\cyrp")
-  ("" "\\CYRR")
-  ("" "\\cyrr")
-  ("" "\\CYRS")
-  ("" "\\cyrs")
-  ("" "\\CYRT")
-  ("" "\\cyrt")
-  ("" "\\CYRU")
-  ("" "\\cyru")
-  ("" "\\CYRF")
-  ("" "\\cyrf")
-  ("" "\\CYRH")
-  ("" "\\cyrh")
-  ("" "\\CYRC")
-  ("" "\\cyrc")
-  ("" "\\CYRCH")
-  ("" "\\cyrch")
-  ("" "\\CYRSH")
-  ("" "\\cyrsh")
-  ("" "\\CYRSHCH")
-  ("" "\\cyrshch")
-  ("" "\\CYRHRDSN")
-  ("" "\\cyrhrdsn")
-  ("" "\\CYRERY")
-  ("" "\\cyrery")
-  ("" "\\CYRSFTSN")
-  ("" "\\cyrsftsn")
-  ("" "\\CYREREV")
-  ("" "\\cyrerev")
-  ("" "\\CYRYU")
-  ("" "\\cyryu")
-  ("" "\\CYRYA")
-  ("" "\\cyrya")
-  ("" "\\CYRYO")
-  ("" "\\cyryo"))
-
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Page size settings
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
