@@ -32,17 +32,11 @@
 (define tmtex-serial 0)
 (define tmtex-auto-produce 0)
 (define tmtex-auto-consume 0)
-(define tmtex-image-root-url (string->url "image"))
+(define tmtex-image-root-url (unix->url "image"))
 (define tmtex-image-root-string "image")
 (define tmtex-appendices? #f)
 (define tmtex-replace-style? #t)
 (define tmtex-indirect-bib? #f)
-(define tmtex-oriental? #f)
-(define tmtex-chinese? #f)
-(define tmtex-japanese? #f)
-(define tmtex-korean? #f)
-(define tmtex-taiwanese? #f)
-(define tmtex-cyrillic? #f)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Style
@@ -56,19 +50,6 @@
 (tm-define (tmtex-style-init body)
   (noop))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;; Language
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-
-(define (tmtex-set-language lan)
-  (set! tmtex-chinese? (== lan "chinese"))
-  (set! tmtex-japanese? (== lan "japanese"))
-  (set! tmtex-korean? (== lan "korean"))
-  (set! tmtex-taiwanese? (== lan "taiwanese"))
-  (set! tmtex-oriental? (or tmtex-chinese? tmtex-japanese?
-			    tmtex-korean? tmtex-taiwanese?))
-  (set! tmtex-cyrillic? (in? lan '("bulgarian" "russian" "ukrainian"))))
-
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Initialization from options
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -82,19 +63,23 @@
       (begin
 	(set! tmtex-image-root-url (url-unglue current-save-target 4))
 	(set! tmtex-image-root-string
-	      (url->string (url-tail tmtex-image-root-url))))
+	      (url->unix (url-tail tmtex-image-root-url))))
       (begin
-	(set! tmtex-image-root-url (string->url "image"))
+	(set! tmtex-image-root-url (unix->url "image"))
 	(set! tmtex-image-root-string "image")))
   (set! tmtex-appendices? #f)
   (set! tmtex-replace-style?
 	(== (assoc-ref opts "texmacs->latex:replace-style") "on"))
   (set! tmtex-indirect-bib?
 	(== (assoc-ref opts "texmacs->latex:indirect-bib") "on"))
-  (set! tmtex-use-catcodes?
-	(== (assoc-ref opts "texmacs->latex:use-catcodes") "on"))
   (set! tmtex-use-macros?
-	(== (assoc-ref opts "texmacs->latex:use-macros") "on")))
+	(== (assoc-ref opts "texmacs->latex:use-macros") "on"))
+  (set! tmtex-use-unicode?
+	(== (assoc-ref opts "texmacs->latex:encoding") "utf-8"))
+  (set! tmtex-use-catcodes? 
+        (== (assoc-ref opts "texmacs->latex:encoding") "cork"))
+  (set! tmtex-use-ascii? 
+        (== (assoc-ref opts "texmacs->latex:encoding") "ascii")))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Data
@@ -258,27 +243,15 @@
 	 (tex-apply 'tmmathbf (tmtex-modified-token 'mathcal s 6)))
 	((string-starts? s "b-up-") (tmtex-modified-token 'mathbf s 5))
 	((string-starts? s "b-") (tmtex-modified-token 'tmmathbf s 2))
-	((and (string-starts? s "#") tmtex-oriental?)
-	 (cond (tmtex-japanese?
-		(let* ((qs (string-append "<" s ">"))
-		       (cv (string-convert qs "Cork" "ISO-2022-JP"))
-		       (ex (list->string (list #\33 #\50 #\102))))
-		  (set! cv (string-append cv ex))
-		  (list '!widechar (string->symbol cv))))
-	       (tmtex-korean?
-		(let* ((qs (string-append "<" s ">"))
-		       (cv (string-convert qs "Cork" "UTF-8")))
-		  (list '!widechar (string->symbol cv))))
-	       ((or tmtex-chinese? tmtex-taiwanese?)
-		(let* ((qs (string-append "<" s ">"))
-		       ;;(cv (string-convert qs "Cork" "cp936")) ; Chinese?
-		       ;;(cv (string-convert qs "Cork" "cp950")) ; Taiwanese ?
-		       (cv (string-convert qs "Cork" "UTF-8")))
-		  (list '!widechar (string->symbol cv))))))
-	((and (string-starts? s "#") tmtex-cyrillic?)
+	((and (string-starts? s "#") (not tmtex-use-catcodes?)) 
 	 	(let* ((qs (string-append "<" s ">"))
 		       (cv (string-convert qs "Cork" "UTF-8")))
-		   (list '!widechar (string->symbol cv))))	 	
+		   (list '!widechar (string->symbol cv))))
+	((and (string-starts? s "#") tmtex-use-catcodes?) 
+	 	(let* ((qs (string-append "<" s ">"))
+                       (us (string-convert qs "Cork" "UTF-8"))
+		       (cv (string-convert us "UTF-8" "LaTeX")))
+		   (list '!widechar (string->symbol cv))))
 	(else (let ((ss (list (string->symbol s))))
 		(cond ((not (logic-in? (car ss) latex-symbol%))
 		       (display* "TeXmacs] non converted symbol: " s "\n")
@@ -316,14 +289,19 @@
 	      ((tmtex-special-char? c)
 	       (cons (list (string->symbol (char->string c)))
 		     (tmtex-text-list (cdr l))))
-	      ((== c #\~) (cons (list '~ " ") (tmtex-text-list (cdr l))))
-	      ((== c #\^) (cons (list '^ " ") (tmtex-text-list (cdr l))))
-	      ((== c #\\) (cons (list 'tmbsl) (tmtex-text-list (cdr l))))
+	      ((== c #\~)  (tmtex-text-sub "\\~{}" l))
+	      ((== c #\^)  (tmtex-text-sub "\\^{}" l))
+	      ((== c #\\)  (tmtex-text-sub "{\\textbackslash}" l))
+	      ((== c #\`)  (tmtex-text-sub "`" l))
 	      ((== c #\21) (tmtex-text-sub "''" l))
 	      ((== c #\22) (tmtex-text-sub ",," l))
 	      ((== c #\25) (tmtex-text-sub "--" l))
 	      ((== c #\26) (tmtex-text-sub "---" l))
-	      (else (cons c (tmtex-text-list (cdr l))))))))
+	      (else 
+		(cons
+		  (if (or tmtex-use-unicode? tmtex-use-ascii?)
+		    (list (string-convert (char->string c) "Cork" "UTF-8")) c)
+		    (tmtex-text-list (cdr l))))))))
 
 (define (tmtex-math-operator l)
   (receive (p q) (list-break l (lambda (c) (not (char-alphabetic? c))))
@@ -473,7 +451,7 @@
   (cons '!document (tmtex-list l)))
 
 (define (tmtex-date l)
-  (tmtex-default "today" l))
+  (tmtex-default "tmdate" l))
 
 (define (tmtex-para l)
   (cons '!paragraph (tmtex-list l)))
@@ -520,6 +498,8 @@
 	(else (cons (car l) (tmtex-rewrite-no-break (cdr l))))))
 
 (define (tmtex-concat l)
+  ;;(display* "l= " l "\n")
+  (set! l (pre-brackets-recurse l))
   (if (tmtex-math-mode?)
       (tex-concat (tmtex-math-concat-spaces (tmtex-list l)))
       (tex-concat (tmtex-list (tmtex-rewrite-no-break l)))))
@@ -601,18 +581,75 @@
 (define (tmtex-htab l)
   (tex-apply 'hspace* (list 'fill)))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Make brackets small when necessary
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(define (disable-large? x level)
+  (cond ((string? x) #t)
+        ((func? x 'concat)
+         (list-and (map (cut disable-large? <> level) (cdr x))))
+        ((tm-in? x '(left mid right)) #t)
+        ((tm-in? x '(lsub lsup rsub rsup))
+         (and (> level 0) (disable-large? (cadr x) (- level 1))))
+        ((tm-in? x '(lprime rprime)) #t)
+        ((tm-in? x '(wide wide*))
+         (disable-large? (cadr x) (- level 1)))
+        ((tm-in? x '(with rigid locus))
+         (disable-large? (cAr x) level))
+        (else #f)))
+
+(define (make-small s)
+  (cond ((nstring? s) "<nobracket>")
+	((== s ".") "<nobracket>")
+	((<= (string-length s) 1) s)
+	(else (string-append "<" s ">"))))
+
+(define (make-small-bracket x)
+  (if (tm-in? x '(left mid right)) (make-small (cadr x)) x))
+
+(define (find-right l)
+  (cond ((null? l) #f)
+        ((func? (car l) 'left) #f)
+        ((func? (car l) 'right) 2)
+        (else (with i (find-right (cdr l)) (and i (+ i 1))))))
+
+(define (pre-brackets l)
+  (cond ((null? l) l)
+        ((func? (car l) 'left)
+         (with n (find-right (cdr l))
+           (if (not n) (cons (car l) (pre-brackets (cdr l)))
+               (let* ((r (pre-brackets (sublist l n (length l))))
+                      (m (sublist l 0 n)))
+                 (if (disable-large? `(concat ,@m) 2)
+                     (begin
+                       ;;(display* "< " m "\n")
+                       ;;(display* "> " (map make-small-bracket m) "\n")
+                       (append (map make-small-bracket m) r))
+                     (append m r))))))
+        (else (cons (car l) (pre-brackets (cdr l))))))
+
+(define (pre-brackets-recurse l)
+  (with r (pre-brackets l)
+    (if (== r l) r
+        (pre-brackets-recurse r))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Mathematics
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+(define (convert-around x)
+  (with d (downgrade-brackets x)
+    (tmtex-concat (if (pair? d) (cdr d) (list d)))))
+
 (define (tmtex-around l)
-  (tmtex-concat (cdr (downgrade-brackets (cons 'around l)))))
+  (convert-around (cons 'around l)))
 
 (define (tmtex-around* l)
-  (tmtex-concat (cdr (downgrade-brackets (cons 'around* l)))))
+  (convert-around (cons 'around* l)))
 
 (define (tmtex-big-around l)
-  (tmtex-concat (cdr (downgrade-brackets (cons 'big-around l)))))
+  (convert-around (cons 'big-around l)))
 
 (define (tmtex-large-decode s)
   (cond ((nstring? s) ".")
@@ -727,6 +764,9 @@
       (tmtex-script '!sup (car l))
       (list 'tmrsup (tmtex (car l)))))
 
+(define (tmtex-modulo l)
+      (tmtex-script 'mod (car l)))
+
 (define (tmtex-frac l)
   (tmtex-function 'frac l))
 
@@ -1063,7 +1103,7 @@
   (tmtex-eps (cons 'graphics l)))
 
 (define (tmtex-as-eps name)
-  (with u (url-relative current-save-target (string->url name))
+  (with u (url-relative current-save-target (unix->url name))
     (if (or (string-ends? name ".ps")
 	    (string-ends? name ".eps")
 	    (not (url-exists? u)))
@@ -1215,6 +1255,33 @@
       (list 'tmtexttt (tmtex (car l)))))
 ;;(list '!verb (tmtex-tt (car l)))))
 
+(define (tmtex-number-renderer l)
+  (let ((r (cond ((string? l) l)
+                 ((list? l) (tmtex-number-renderer (car l)))
+                 (else ""))))
+    (cond
+      ((== r "alpha") "alph")
+      ((== r "Alpha") "Alph")
+      (else      r))))
+
+(define (tmtex-number-counter l)
+  (cond ((func? l 'value) (tmtex-number-counter (cdr l)))
+        ((and (list? l) (== 1 (length l))) (tmtex-number-counter (car l)))
+        ((symbol? l) (tmtex-number-counter (symbol->string l)))
+        ((string? l) (if (string-ends? l "-nr") (string-drop-right l 3) l))
+        (else "")))
+
+(define (tmtex-number l)
+  (tmtex-default 
+    (tmtex-number-renderer (cdr l))
+    (list (tmtex-number-counter (car l)))))
+
+(define (tmtex-change-case l)
+  (cond
+    ((== (cadr l) "UPCASE") (tex-apply 'MakeUppercase (tmtex (car l))))
+    ((== (cadr l) "locase") (tex-apply 'MakeLowercase (tmtex (car l))))
+    (else (tmtex (car l)))))
+
 (define (tmtex-indent s l)
   (list (list '!begin "tmindent") (tmtex (car l))))
 
@@ -1276,7 +1343,7 @@
     r))
 
 (define (tmtex-math-up s l)
-  (list 'mathup (tmtex-textual (car l))))
+  (list 'mathrm (tmtex-textual (car l))))
 
 (define (tmtex-math-ss s l)
   (list 'mathsf (tmtex-textual (car l))))
@@ -1317,8 +1384,8 @@
 (define (tmtex-syntax s l)
   (tmtex (car l)))
 
-(define (tmtex-dummy s l)
-  "")
+(define (tmtex-theindex s l)
+    (list 'printindex))
 
 (define (tmtex-toc s l)
   (tex-apply 'tableofcontents))
@@ -1568,6 +1635,8 @@
   (float tmtex-float)
   ((:or datoms dlines dpages dbox) tmtex-noop)
 
+  (number tmtex-number)
+  (change-case tmtex-change-case)
   (with-limits tmtex-noop)
   (line-break tmtex-line-break)
   (new-line tmtex-new-line)
@@ -1602,6 +1671,7 @@
   (lsup tmtex-lsup)
   (rsub tmtex-rsub)
   (rsup tmtex-rsup)
+  (modulo tmtex-modulo)
   (frac tmtex-frac)
   (sqrt tmtex-sqrt)
   (wide tmtex-wide)
@@ -1633,7 +1703,7 @@
   (syntax tmtex-syntax)
 
   ((:or or xor and not plus minus times over div mod
-	merge length range number translate change-case find-file
+	merge length range translate find-file
 	is-tuple look-up
 	equal unequal less lesseq greater greatereq) tmtex-noop)
 
@@ -1749,7 +1819,7 @@
   ((:or eqnarray eqnarray* leqnarray*) (,tmtex-eqnarray 1))
   (eq-number (,tmtex-default -1))
 
-  (the-index (,tmtex-dummy -1))
+  (the-index (,tmtex-theindex -1))
   (glossary (,tmtex-glossary 1))
   (glossary-explain (,tmtex-glossary 2))
   (glossary-2 (,tmtex-glossary-entry 3))
@@ -1867,17 +1937,14 @@
 	     (doc (list '!file body style lan init (get-texmacs-path))))
 	(latex-set-style main-style)
 	(latex-set-packages '())
-	(latex-set-language lan)
 	(set! tmtex-style (car style))
 	(set! tmtex-packages (cdr style))
 	(when (elsevier-style?)
 	  (import-from (convert latex tmtex-elsevier)))
 	(tmtex-style-init body)
-	(tmtex-set-language lan)
 	(with result (texmacs->latex doc opts)
 	  (set! tmtex-style "generic")
 	  (set! tmtex-packages '())
-	  (tmtex-set-language "english")
 	  result))
       (let* ((x2 (tmtm-eqnumber->nonumber x))
 	     (x3 (tmtm-match-brackets x2)))
@@ -1885,6 +1952,4 @@
 	(with r (tmtex (tmpre-produce x3))
 	  (if (not tmtex-use-macros?)
 	      (set! r (latex-expand-macros r)))
-	  (if (not tmtex-use-catcodes?)
-	      (set! r (latex-expand-catcodes r)))
 	  r))))
