@@ -21,7 +21,7 @@
 (define help-file-path "$TEXMACS_DOC_PATH")
 
 (tm-define (url-exists-in-help? s)
-  (url-exists? (url help-file-path s)))
+  (url-exists? (url-unix help-file-path s)))
 
 (define (url-resolve-help s)
   (if (or (in? (url-suffix s) '("tex" "tm")) (url-exists? s))
@@ -46,25 +46,21 @@
 			((== lan "ukrainian") ".uk.tm")
 			(else ".en.tm")))
 	     (dir help-file-path))
-	(cond ((url-exists? (url dir (string-append s suf)))
-	       (url-resolve (url dir (string-append s suf)) "r"))
+	(cond ((url-exists? (url-unix dir (string-append s suf)))
+	       (url-resolve (url-unix dir (string-append s suf)) "r"))
 	      ((and (!= suf ".en.tm")
-		    (url-exists? (url dir (string-append s ".en.tm"))))
-	       (url-resolve (url dir (string-append s ".en.tm")) "r"))
+		    (url-exists? (url-unix dir (string-append s ".en.tm"))))
+	       (url-resolve (url-unix dir (string-append s ".en.tm")) "r"))
 	      (else (url-none))))))
 
 (define (load-help-buffer-sub s type)
   (let ((name (url-resolve-help s)))
-    (if (url-none? name)
-	(set-message `(concat "Error: help file " (verbatim ,s) " not found")
-		     "load help file")
-	(cond ((== type "normal")
-	       (let ((doc (texmacs-load-tree name "help")))
-		 (if (== (tree->stree doc) "error")
-		     (set-message "Bad help file" "load help file")
-		     (set-help-buffer name doc))))
-	      ((== type "article") (tmdoc-expand-help name 'tmdoc-title))
-	      ((== type "book") (tmdoc-expand-help-manual name))))))
+    (cond ((url-none? name)
+           (set-message
+            `(concat "Error: help file " (verbatim ,s) " not found")
+            "load help file"))
+          ((== type "book") (tmdoc-expand-help-manual name))
+          (else (tmdoc-expand-help name type)))))
 
 (tm-define (load-help-buffer s) (load-help-buffer-sub s "normal"))
 (tm-define (load-help-article s) (load-help-buffer-sub s "article"))
