@@ -214,7 +214,6 @@
       (when (url-exists-in-help? "devel/scheme/scheme.en.tm")
 	(-> "Scheme extensions"
 	    ("Browse" (load-help-buffer "devel/scheme/scheme"))
-      ("List all commands" (help-all-scheme-commands))
 	    ---
 	    ("Overview of the scheme extension language"
 	     (load-help-article "devel/scheme/overview/scheme-overview"))
@@ -222,12 +221,17 @@
 	     (load-help-article "devel/scheme/utils/scheme-utils"))
 	    ("Programming routines for editing documents"
 	     (load-help-article "devel/scheme/edit/scheme-edit"))
+	    ("Program interface for buffer management"
+	     (load-help-article "devel/scheme/buffer/scheme-buffer"))
 	    ("Scheme interface for the graphical mode"
 	     (load-help-article "devel/scheme/graphics/scheme-graphics"))
-      ("Customizing and extending the user interface"
-       (load-help-article "devel/scheme/gui/scheme-gui"))
+            
+            ("Customizing and extending the user interface"
+             (load-help-article "devel/scheme/gui/scheme-gui"))
 	    ("Writing TeXmacs bibliography styles"
-	     (load-help-article "devel/scheme/bibliography/bibliography")))))
+	     (load-help-article "devel/scheme/bibliography/bibliography"))
+            ---
+            ("List all commands" (help-all-scheme-commands)))))
   ---
   (-> "Search"
       ("Documentation" (interactive docgrep-in-doc))
@@ -244,8 +248,8 @@
 	    ("Developers guide" (load-help-book "devel/source/source")))
 	  ---
 	  (when (style-has? "tmdoc-style")
-	    ("Compile article" (tmdoc-expand-this 'tmdoc-title))
-	    ("Compile book" (tmdoc-expand-this 'title))))
+	    ("Compile article" (tmdoc-expand-this "article"))
+	    ("Compile book" (tmdoc-expand-this "book"))))
 ;;       (when (url-exists-in-path? "wget")
 ;; 	(-> "Online help"
 ;; 	    ("Wiki" (load-buffer "tmfs://file/+R28HzRqmu}tA69.scm"))
