@@ -19,17 +19,17 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (define (tmweb-make-dir dir html-dir)
-  (when (and (!= dir html-dir) (!= dir (string->url ".")))
+  (when (and (!= dir html-dir) (!= dir (system->url ".")))
     (tmweb-make-dir (url-expand (url-append dir (url-parent))) html-dir))
   (when (not (url-exists? dir))
-    (display* "TeXmacs] Creating directory " (url->string dir) "\n")
+    (display* "TeXmacs] Creating directory " (url->system dir) "\n")
     (system-mkdir dir)
     (system-1 "chmod a+x" dir)))
 
 (define (tmweb-convert-file tm-file html-file)
   (with-aux tm-file
     (if (url? html-file) (set! current-save-target html-file))
-    (texmacs-save-buffer html-file "html")))
+    (export-buffer-main (current-buffer) html-file "html" (list :overwrite))))
 
 (define (needs-update? src dest update?)
   (or (not update?)
@@ -42,29 +42,29 @@
 	 (u2 (url-glue (url-unglue u1 2) (if m? "xhtml" "html")))
 	 (u3 (url-append html-dir u2))
 	 (dir (url-expand (url-append u3 (url-parent))))
-	 (dir-name (url->string (url-tail dir))))
+	 (dir-name (url->system (url-tail dir))))
     (when (and (!= dir-name "CVS") (!= dir-name ".svn")
 	       (!= dir-name "prop-base") (!= dir-name "text-base"))
       (tmweb-make-dir dir (url-expand html-dir))
       (when (needs-update? file u3 update?)
-        (system-wait "Converting" (url->string u1))
-        (display* "TeXmacs] Converting " (url->string u1) "\n")
+        (system-wait "Converting" (url->system u1))
+        (display* "TeXmacs] Converting " (url->system u1) "\n")
         (tmweb-convert-file file u3)))))
 
 (define (tmweb-copy-file-dir file tm-dir html-dir update?)
   (let* ((u1 (url-delta (url-append tm-dir "dummy") file))
 	 (u2 (url-append html-dir u1))
-	 (name (url->string (url-tail u2)))
+	 (name (url->system (url-tail u2)))
 	 (dir (url-expand (url-append u2 (url-parent))))
-	 (dir-name (url->string (url-tail dir))))
+	 (dir-name (url->system (url-tail dir))))
     (when (and (!= dir-name "CVS") (!= dir-name ".svn")
 	       (!= dir-name "prop-base") (!= dir-name "text-base")
 	       (not (string-ends? name "~"))
                (not (string-ends? name "#")))
       (tmweb-make-dir dir (url-expand html-dir))
       (when (needs-update? file u2 update?)
-        (system-wait "Copying" (url->string u1))
-        (display* "TeXmacs] Copying " (url->string u1) "\n")
+        (system-wait "Copying" (url->system u1))
+        (display* "TeXmacs] Copying " (url->system u1) "\n")
         (system-copy file u2)))))
 
 (define (tmweb-convert-directory tm-dir html-dir update?)
