@@ -378,7 +378,8 @@
     (insert-go-to s '(2 1 1 0 0))
     (with-innermost t field-input-context?
       (with u (tree-ref t :previous 0)
-	(if (url-exists? (url "$TEXMACS_STYLE_PATH" (string-append lan ".ts")))
+	(if (url-exists? (url-unix "$TEXMACS_STYLE_PATH"
+				   (string-append lan ".ts")))
 	    (init-add-package lan))
 	(session-feed lan ses :start u t '())))))
 
