@@ -502,9 +502,9 @@
 	  ("Default" (init-default "par-mode"))
 	  ---
 	  ("Justified" (init-env "par-mode" "justify"))
-	  ("Left ragged" (init-env "par-mode" "left"))
+	  ("Left aligned" (init-env "par-mode" "left"))
 	  ("Centered" (init-env "par-mode" "center"))
-	  ("Right ragged" (init-env "par-mode" "right")))
+	  ("Right aligned" (init-env "par-mode" "right")))
       (-> "Hyphenation"
 	  ("Default" (init-default "par-hyphen"))
 	  ---
@@ -587,10 +587,10 @@
 	      ("Other" (init-interactive-env "page-flexibility")))))
   ---
   (-> "Update"
-      ("All" (generate-all-aux) (update-buffer))
+      ("All" (generate-all-aux) (image-gc) (inclusions-gc) (update-current-buffer))
       ---
-      ("Buffer" (update-buffer))
-      ("Bibliography" (generate-all-aux) (update-buffer))
+      ("Buffer" (update-current-buffer))
+      ("Bibliography" (generate-all-aux) (update-current-buffer))
 ;;    ("Bibliography" (generate-aux "bibliography"))
       ("Table of contents" (generate-aux "table-of-contents"))
       ("Index" (generate-aux "index"))
