@@ -175,6 +175,9 @@
 (lazy-define (doc docgrep) docgrep-in-doc docgrep-in-src docgrep-in-texts)
 (lazy-define (doc tmweb) tmweb-convert-dir tmweb-update-dir
              tmweb-interactive-build tmweb-interactive-update)
+(lazy-tmfs-handler (doc docgrep) grep)
+(lazy-tmfs-handler (doc tmdoc) help)
+(lazy-tmfs-handler (doc scheme-help) scheme-help)
 (define-secure-symbols tmdoc-include)
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
 
@@ -186,6 +189,8 @@
 (lazy-format (convert bibtex init-bibtex) bibtex)
 (lazy-format (convert images init-images)
 	     postscript pdf xfig xmgrace svg xpm jpeg ppm gif png pnm)
+(lazy-define (convert images tmimage)
+	     export-selection-as-graphics clipboard-copy-image)
 (lazy-define (convert rewrite init-rewrite) texmacs->code texmacs->verbatim)
 (lazy-define (convert html tmhtml-expand) tmhtml-env-patch)
 (lazy-define (convert latex latex-drd) latex-arity latex-type)
@@ -195,13 +200,13 @@
 
 ;(display "Booting remote facilities\n")
 (lazy-define (remote tmfs-remote) remote-load remote-save
-	     remote-name remote-permission? remote-project-load-by-name)
+	     remote-title remote-permission? remote-project-load-by-name)
 (lazy-menu (remote remote-menu) remote-menu)
 (lazy-menu (remote chat-menu) chat-menu)
 (lazy-menu (remote tmfs-menu) remote-file-menu)
 (tmfs-handler #t 'load remote-load)
 (tmfs-handler #t 'save remote-save)
-(tmfs-handler #t 'name remote-name)
+(tmfs-handler #t 'title remote-title)
 (tmfs-handler #t 'permission? remote-permission?)
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
 
@@ -218,6 +223,7 @@
 ;(display "Booting versioning facilities\n")
 (lazy-menu (version version-menu) version-menu)
 (lazy-keyboard (version version-kbd) with-versioning-tool?)
+(lazy-define (version version-tmfs) update-buffer commit-buffer)
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
 
 ;(display "Booting debugging facilities\n")
@@ -235,6 +241,6 @@
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
 
 ;(display "------------------------------------------------------\n")
-(delayed (:idle 10000) (delayed-auto-save))
+(delayed (:idle 10000) (autosave-delayed))
 (texmacs-banner)
 ;(display "Initialization done\n")
