@@ -458,6 +458,9 @@
 (tm-define-macro ($strong . l)
   ($quote `(strong ($unquote ($inline ,@l)))))
 
+(tm-define-macro ($verbatim . l)
+  ($quote `(verbatim ($unquote ($inline ,@l)))))
+
 (tm-define-macro ($link dest . l)
   ($quote `(hlink ($unquote ($inline ,@l)) ($unquote ($textual ,dest)))))
 
@@ -465,11 +468,19 @@
 ;; Specific markup for TeXmacs documentation
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+(tm-define-macro ($generic . l)
+  ($quote
+   `(document
+      (TeXmacs ,(texmacs-version))
+      (style (tuple "generic"))
+      (body ($unquote ($block ,@l))))))
+
 (tm-define-macro ($tmdoc . l)
   (with lan (get-output-language)
     ($quote
       `(document
-         (style "tmdoc")
+         (TeXmacs ,(texmacs-version))
+         (style (tuple "tmdoc"))
          (body ($unquote ($localize ($block ,@l))))
          (initial (collection (associate "language" ,lan)))))))
 
@@ -479,6 +490,9 @@
 (tm-define-macro ($tmdoc-title . l)
   ($quote `(document (tmdoc-title ($unquote ($inline ,@l))))))
 
+(tm-define-macro ($tmfs-title . l)
+  ($quote `(document (tmfs-title ($unquote ($inline ,@l))))))
+
 (tm-define-macro ($folded-documentation key . l)
   ($quote `(document (folded-documentation ($unquote ($inline ,key))
                                            ($unquote ($block ,@l))))))
