@@ -801,24 +801,24 @@
 
 (tm-define (top-window menu-promise name)
   (:interactive #t)
-  (let* ((win (window-handle))
-	 (qui (object->command (lambda () (window-delete win))))
+  (let* ((win (alt-window-handle))
+	 (qui (object->command (lambda () (alt-window-delete win))))
 	 (men (menu-promise))
 	 (scm (list 'vertical men))
 	 (wid (make-menu-widget scm 0)))
-    (window-create-quit win wid name qui)
-    (window-show win)))
+    (alt-window-create-quit win wid name qui)
+    (alt-window-show win)))
 
 (tm-define (dialogue-window menu-promise cmd name)
   (:interactive #t)
-  (let* ((win (window-handle))
-	 (qui (object->command (lambda () (window-delete win))))
-	 (lbd (lambda x (apply cmd x) (window-delete win)))
+  (let* ((win (alt-window-handle))
+	 (qui (object->command (lambda () (alt-window-delete win))))
+	 (lbd (lambda x (apply cmd x) (alt-window-delete win)))
 	 (men (menu-promise lbd))
 	 (scm (list 'vertical men))
 	 (wid (make-menu-widget scm 0)))
-    (window-create-quit win wid name qui)
-    (window-show win)))
+    (alt-window-create-quit win wid name qui)
+    (alt-window-show win)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Other top-level windows
@@ -826,12 +826,12 @@
 
 (tm-define (interactive-window wid-promise cmd name)
   (:interactive #t)
-  (let* ((win (window-handle))
-	 (lbd (lambda x (apply cmd x) (window-delete win)))
+  (let* ((win (alt-window-handle))
+	 (lbd (lambda x (apply cmd x) (alt-window-delete win)))
 	 (com (object->command (menu-protect lbd)))
 	 (wid (wid-promise com)))
-    (window-create win wid name #t)
-    (window-show win)))
+    (alt-window-create win wid name #t)
+    (alt-window-show win)))
 
 (tm-define (interactive-print done u)
   (:interactive #t)
