@@ -310,7 +310,7 @@
 
 (define (build-navigation-page-sub style l)
   (with doc (navigation-list->document style l)
-    (set-aux-buffer "Link page" "Link page" doc)))
+    (open-auxiliary "Link page" doc)))
 
 (define (build-navigation-page l)
   (let* ((style (tree->stree (get-style-tree)))
@@ -345,10 +345,10 @@
   (with (name label) (decompose-url name-label)
     (cond ((== name "") (go-to-label label))
 	  ((== label "")
-	   (with u (url-relative (get-name-buffer) name)
+	   (with u (url-relative (buffer-master) name)
 	     (load-browse-buffer u)))
 	  (else
-	   (with u (url-relative (get-name-buffer) name)
+	   (with u (url-relative (buffer-master) name)
 	     (load-browse-buffer u)
 	     (go-to-label label)))))
   (if (nnull? opt-from) (cursor-history-add (cursor-path))))
