@@ -158,10 +158,12 @@
 		     "texmacs->latex:expand-user-macros"))
 	    (toggle ("Export bibliographies as links"
 		     "texmacs->latex:indirect-bib"))
-	    (toggle ("Use catcode definitions in preamble"
-		     "texmacs->latex:use-catcodes"))
 	    (toggle ("Allow for macro definitions in preamble"
-		     "texmacs->latex:use-macros")))
+		     "texmacs->latex:use-macros"))
+	    (enum ("Encoding" "texmacs->latex:encoding")
+                  ("Strict Ascii" "ascii")
+                  ("Cork charset with TeX catcode definition in preamble" "cork")
+                  ("Utf-8 with inputenc LaTeX package" "utf-8")))
 	(-> "TeXmacs -> Verbatim"
 	    (toggle ("Wrap lines"
 		     "texmacs->verbatim:wrap"))
@@ -175,7 +177,14 @@
 	    (enum ("Encoding" "verbatim->texmacs:encoding")
 		  ("Cork" "cork")
 		  ("Iso-8859-1" "iso-8859-1")
-		  ("Utf-8" "utf-8"))))
+		  ("Utf-8" "utf-8")))
+	(-> "TeXmacs -> Image"
+	    (enum ("Format" "texmacs->graphics:format")
+		  ("Svg" "svg")
+		  ("Eps" "eps")
+		  ("Png" "png"))
+            (toggle ("Embed in svg as attr" "texmacs->graphics:attr"))
+            (toggle ("Embed in svg as tmml" "texmacs->graphics:tmml"))))
     (-> "Mathematics"
         (-> "Keyboard"
             (item ("Enforce brackets to match" (toggle-matching-brackets)))
@@ -439,6 +448,11 @@
       (toggle (set-boolean-preference "texmacs->html:images" answer)
               (get-boolean-preference "texmacs->html:images")))))
 
+(define-preference-names "texmacs->latex:encoding"
+  ("Strict Ascii" "ascii")
+  ("Cork charset with catcode definitions in preamble" "cork")
+  ("Unicode with inputenc LaTeX package" "utf-8"))
+
 (tm-widget (latex-preferences-widget)
   ===
   (bold (text "TeXmacs -> LaTeX"))
@@ -456,12 +470,18 @@
     (meti (text "Export bibliographies as links")
       (toggle (set-boolean-preference "texmacs->latex:indirect-bib" answer)
               (get-boolean-preference "texmacs->latex:indirect-bib")))
-    (meti (text "Allow for catcode definitions in preamble")
-      (toggle (set-boolean-preference "texmacs->latex:use-catcodes" answer)
-              (get-boolean-preference "texmacs->latex:use-catcodes")))
     (meti (text "Allow for macro definitions in preamble")
       (toggle (set-boolean-preference "texmacs->latex:use-macros" answer)
-              (get-boolean-preference "texmacs->latex:use-macros")))))
+              (get-boolean-preference "texmacs->latex:use-macros"))))
+  ===
+  (aligned
+    (item (text "Character encoding:")
+      (enum (set-pretty-preference "texmacs->latex:encoding" answer)
+            '("ascii" "cork" "utf-8")
+            (get-pretty-preference "texmacs->latex:encoding")
+            "5em"))))
+
+;;;;;;;;;;;;;;
 
 (define-preference-names "texmacs->verbatim:encoding"
   ("cork" "Cork")
@@ -503,6 +523,33 @@
             (get-pretty-preference "verbatim->texmacs:encoding")
             "5em"))))
 
+(define-preference-names "texmacs->graphics:format"
+  ("svg" "Svg")
+  ("eps" "Eps")
+  ("png" "Png"))
+
+(tm-widget (image-preferences-widget)
+  ===
+  (bold (text "TeXmacs -> Image"))
+  ===
+  (aligned
+    (item (text "Format:")
+      (enum (set-pretty-preference "texmacs->graphics:format" answer)
+            '("Svg" "Eps" "Png")
+            (get-pretty-preference "texmacs->graphics:format")
+            "5em")))
+  (when (== (get-preference "texmacs->graphics:format") "svg")
+    ===
+    (aligned
+      (meti (text "Embed TeXmacs data in Svg as string attribute")
+        (toggle (set-boolean-preference "texmacs->graphics:attr" answer)
+                (get-boolean-preference "texmacs->graphics:attr"))))
+    ===
+    (aligned
+      (meti (text "Embed TeXmacs data in Svg as tmml")
+        (toggle (set-boolean-preference "texmacs->graphics:tmml" answer)
+                (get-boolean-preference "texmacs->graphics:tmml"))))))
+
 (tm-widget (conversion-preferences-widget)
   ======
   (tabs
@@ -514,7 +561,10 @@
         (dynamic (latex-preferences-widget))))
     (tab (text "Verbatim")
       (centered
-        (dynamic (verbatim-preferences-widget))))))
+        (dynamic (verbatim-preferences-widget))))
+    (tab (text "Image")
+      (centered
+        (dynamic (image-preferences-widget))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Preferences widget
