@@ -40,9 +40,9 @@
       (-> "Import" (link clipboard-import-preference-menu))
       (-> "Export" (link clipboard-export-preference-menu)))
   (-> "Update"
-      ("Image links" (image-gc))
+      ("Styles" (style-clear-cache))
       ("Inclusions" (inclusions-gc))
-      ("Styles" (style-clear-cache)))
+      ("Linked images" (image-gc)))
   (-> "Web"
       ("Create web site" (tmweb-interactive-build))
       ("Update web site" (tmweb-interactive-update)))
