@@ -54,7 +54,10 @@
     with-aux with-action with-module with-cursor with-server
     user-ask
     tab form item meti
-    $when $let $let* $for))
+    $when $let $let* $for
+    tmfs-load-handler tmfs-save-handler
+    tmfs-title-handler tmfs-permission-handler
+    tmfs-master-handler tmfs-format-handler))
 
 (setq unary-definitions
   '(define define-public define-macro define-public-macro
@@ -63,7 +66,7 @@
     tm-menu define-menu tm-widget define-widget tm-generate
     tm-build tm-build-macro tm-build-widget
     menu-bind define-table extend-table
-    define-format define-language))
+    define-format define-language define-graphics))
 
 (setq unary-no-highlight
   '(format interactive
@@ -94,7 +97,7 @@
     define-secure-symbols map-in-order link promise
     plugin-input-converters use-modules export import-from inherit-modules
     lazy-menu lazy-keyboard lazy-define lazy-initialize
-    lazy-format lazy-language lazy-input-converter
+    lazy-format lazy-language lazy-input-converter lazy-tmfs-handler
     $if))
 
 (setq highlight-definitions
