@@ -69,7 +69,7 @@ is_punctuation (register char c) {
 
 bool
 is_space (register char c) {
-  return (c == ' ') || (c == '\11') || (c == '\12') || (c == '\15');\
+  return (c == ' ') || (c == '\11') || (c == '\12') || (c == '\15');
 }
 
 /******************************************************************************
@@ -1216,8 +1216,8 @@ recompose (array<string> a, string sep) {
 string
 trim_spaces (string s) {
   int start, end;
-  for (start=0; start<N(s) && is_space (s[start]); start++);
-  for (end=N(s); end>start && is_space (s[end]); end--);
+  for (start=0; start<N(s) && is_space (s[start]); start++) ;
+  for (end=N(s); end>start && is_space (s[end]); end--) ;
   return s (start, end);
 }
 
