@@ -103,7 +103,7 @@ converter_rep::load () {
   // to handle each case individually seems unelegant, but there is simply more
   // to be done here than just loading a file.
   // cout << "TeXmacs] load converter " << from << " -> " << to << "\n";
-  if ( from=="Cork" && to=="UTF-8" ) {
+  if (from=="Cork" && to=="UTF-8" ) {
     hashtree<char,string> dic;
     hashtree_from_dictionary (dic,"corktounicode", BIT2BIT, UTF8, false);
     hashtree_from_dictionary (dic,"cork-unicode-oneway", BIT2BIT, UTF8, false);
@@ -112,7 +112,7 @@ converter_rep::load () {
     hashtree_from_dictionary (dic,"symbol-unicode-math", BIT2BIT, UTF8, false);
     ht = dic;
   }
-  else if ( from=="UTF-8" && to=="Cork") {
+  else if (from=="UTF-8" && to=="Cork") {
     hashtree<char,string> dic;
     hashtree_from_dictionary (dic,"corktounicode", UTF8, BIT2BIT, true);
     hashtree_from_dictionary (dic,"unicode-cork-oneway", UTF8, BIT2BIT, false);
@@ -120,13 +120,14 @@ converter_rep::load () {
     hashtree_from_dictionary (dic,"unicode-symbol-oneway", UTF8, BIT2BIT, true);
     ht = dic;
   }
-  else if ( from=="UTF-8" && to=="HTML") {
+  else if (from=="UTF-8" && to=="HTML") {
     hashtree<char,string> dic;
     hashtree_from_dictionary (dic, "HTMLlat1"   , CHAR_ENTITY, ENTITY_NAME, true);
     hashtree_from_dictionary (dic, "HTMLspecial", CHAR_ENTITY, ENTITY_NAME, true);
     hashtree_from_dictionary (dic, "HTMLsymbol" , CHAR_ENTITY, ENTITY_NAME, true);
     ht = dic;
-  } else if ( from=="T2A" && to=="UTF-8" ) {
+  }
+  else if (from=="T2A" && to=="UTF-8" ) {
     hashtree<char,string> dic;
     hashtree_from_dictionary (dic,"corktounicode", BIT2BIT, UTF8, false);
     hashtree_from_dictionary (dic,"cork-unicode-oneway", BIT2BIT, UTF8, false);
@@ -136,6 +137,22 @@ converter_rep::load () {
     hashtree_from_dictionary (dic,"t2atounicode", BIT2BIT, UTF8, false);
     ht = dic;
   }  
+  else if (from=="T2A.CY" && to=="CODEPOINT" ) {
+    hashtree<char,string> dic;
+    hashtree_from_dictionary (dic,"t2atounicode", BIT2BIT, CHAR_ENTITY, false);
+    hashtree_from_dictionary (dic,"t2atounicode", CHAR_ENTITY, CHAR_ENTITY, false);
+    ht = dic;
+  }
+  else if (from=="UTF-8" && to=="LaTeX" ) {
+    hashtree<char,string> dic;
+    hashtree_from_dictionary (dic,"utf8tolatex", CHAR_ENTITY, BIT2BIT, false);
+    ht = dic;
+  }
+  else if (from=="Cork" && to=="ASCII") {
+    hashtree<char,string> dic;
+    hashtree_from_dictionary (dic, "cork-escaped-to-ascii", BIT2BIT, UTF8, false);
+    ht = dic;
+  }   
 }
 
 /******************************************************************************
@@ -154,6 +171,8 @@ convert (string input, string from, string to) {
     return convert_from_cork (input, to);
   else if (to == "Cork")
     return convert_to_cork (input,from);
+  else if (from == "UTF-8" && to == "LaTeX")
+    return convert_utf8_to_LaTeX (input);
   else
     return convert_using_iconv (input, from, to);
 }
@@ -163,15 +182,40 @@ convert_to_cork (string input, string from) {
   string str;
   if (from != "UTF-8")
     str = convert_using_iconv (input, from, "UTF-8");
-  return utf8_to_cork (str);
+  return utf8_to_cork (input);
 }
 
 string 
 convert_from_cork (string input, string to) {
-  string str = cork_to_utf8 (input);
+  string str;
   if (to != "UTF-8")
     str = convert_using_iconv (str, "UTF-8", to);
-  return str;
+  return cork_to_utf8 (input);
+}
+
+string
+convert_utf8_to_LaTeX (string input) {
+  converter conv= load_converter ("UTF-8", "LaTeX");
+  int i, start, n= N(input);
+  string output, r;
+  for (i=0; i<n; ) {
+    if (((unsigned char) input[i]) < 128 && ((unsigned char) input[i]) > 31) {
+      output << input[i++];
+      continue;
+    }
+    else {
+      start = i;
+      string hex_code = '#' * as_hexadecimal (decode_from_utf8 (input, i));
+      r = apply (conv, hex_code);
+      if (r != hex_code) output << r;
+      else {
+	output << input(start, i);
+        cout << "TeXmacs] non ascii character " << hex_code << " on output: "
+          << input(start, i) << "\nLaTeX output may not compile.\n";
+      }
+    }
+  }
+  return output;
 }
 
 string
@@ -208,6 +252,44 @@ cork_to_utf8 (string input) {
   return r;
 }
 
+string
+utf8_to_t2a (string input) {
+  converter conv= load_converter ("UTF-8", "T2A");
+  int start, i, n= N(input);
+  string output;
+  for (i=0; i<n; ) {
+    start= i;
+    unsigned int code= decode_from_utf8 (input, i);
+    string s= input (start, i);
+    string r= apply (conv, s);
+    if (r == s && code >= 256)
+      r= "<#" * as_hexadecimal (code) * ">";
+    output << r;
+  }
+  return output;
+}
+
+string
+cyrillic_subset_in_t2a_to_code_point (string input) {
+  converter conv= load_converter ("T2A.CY", "CODEPOINT");
+  string r, tmp;
+  int i, j, n = N(input);
+
+  for (i = 0 ; i < n ; i++) {
+    if (input[i] == '<') {
+      for (j = i + 1 ; j < n && input[j] != '>' ; j++) ;
+      r << input(i, j+1);
+      i = j;
+    }
+    else {
+      tmp = apply (conv, input[i]);
+      if (tmp == input[i]) r << tmp;
+      else r << '<'*tmp*'>';
+    }
+  }
+  return r;
+}
+
 string
 t2a_to_utf8 (string input) {
   converter conv= load_converter ("T2A", "UTF-8");
@@ -232,6 +314,12 @@ utf8_to_html (string input) {
   return utf8_to_hex_entities(s);
 }
 
+string
+cork_to_ascii (string input) {
+  converter conv = load_converter ("Cork", "ASCII");
+  return apply (conv, input);
+}
+
 #ifdef USE_ICONV
 
 // auto_array<T> objects ensure that the contained array is deleted when the
@@ -335,6 +423,7 @@ bool check_using_iconv (string input, string encoding) {
 
 string
 convert_using_iconv (string input, string from, string to) {
+  if (from == to) return input;
 #ifdef USE_ICONV
   iconv_converter conv (from, to, true);
   return apply (conv, input);
@@ -353,11 +442,13 @@ convert_using_iconv (string input, string from, string to) {
 
 void
 put_prefix_code (string key, string value, hashtree<char,string> tree) {
+  /*
   if (DEBUG_STD) {
     hashtree<char,string> ht= find_node (key,tree);
     if (ht->label != "")
       cout << "overwriting: " << ht->label << " with " << value << '\n';
   }
+  */
   find_node (key,tree)->set_label(value);
 }
 
