@@ -28,18 +28,11 @@ bool enable_fastenv= false;
 * Contructors, destructors and notification of modifications
 ******************************************************************************/
 
-static bool
-is_aux (url u) {
-  if (!is_atomic (u->t)) return false;
-  string s= u->t->label;
-  return starts (s, "* ") && ends (s, " *");
-}
-
 edit_typeset_rep::edit_typeset_rep ():
   the_style (TUPLE),
   cur (hashmap<string,tree> (UNINIT)),
   pre (UNINIT), init (UNINIT), fin (UNINIT),
-  env (drd, is_aux (buf->buf->name)? buf->buf->extra: buf->buf->name,
+  env (drd, buf->buf->master,
        buf->data->ref, (buf->prj==NULL? buf->data->ref: buf->prj->data->ref),
        buf->data->aux, (buf->prj==NULL? buf->data->aux: buf->prj->data->aux)),
   ttt (new_typesetter (env, subtree (et, rp), reverse (rp))) {}
@@ -84,7 +77,7 @@ edit_typeset_rep::add_init (hashmap<string,tree> H) {
 }
 
 void
-edit_typeset_rep::set_base_name (url name) {
+edit_typeset_rep::set_master (url name) {
   env->base_file_name= name;
 }
 
@@ -134,6 +127,7 @@ use_modules (tree t) {
 
 void
 edit_typeset_rep::typeset_style_use_cache (tree style) {
+  style= preprocess_style (style, buf->buf->master);
   //cout << "Typesetting style using cache " << style << LF;
   bool ok;
   hashmap<string,tree> H;
@@ -147,11 +141,11 @@ edit_typeset_rep::typeset_style_use_cache (tree style) {
   if (!ok) {
     //cout << "Typeset without cache " << style << LF;
     if (!is_tuple (style)) FAILED ("tuple expected as style");
-    tree t (USE_PACKAGE, A (style));
-    env->exec (t);
-    env->read_env (H);
-    drd->heuristic_init (H);
+    H= get_style_env (style);
+    drd= get_style_drd (style);
     style_set_cache (style, H, drd->get_locals ());
+    env->patch_env (H);
+    drd->set_environment (H);
   }
   use_modules (env->read (THE_MODULES));
 }
@@ -556,7 +550,8 @@ void
 edit_typeset_rep::init_env (string var, tree by) {
   if (init (var) == by) return;
   init (var)= by;
-  require_save();
+  if (var != PAGE_SCREEN_WIDTH && var != PAGE_SCREEN_HEIGHT)
+    require_save ();
   notify_change (THE_ENVIRONMENT);
 }
 
