@@ -13,19 +13,19 @@
 #define EDITOR_H
 #include "typesetter.hpp"
 #ifdef AQUATEXMACS
-#include "Cocoa/aqua_simple_widget.h"
+#  include "Cocoa/aqua_simple_widget.h"
 #else
-#ifdef QTTEXMACS
-#include "Qt/qt_simple_widget.hpp"
-#else
-#include "Widkit/simple_wk_widget.hpp"
-#endif
+#  ifdef QTTEXMACS
+#    include "Qt/qt_simple_widget.hpp"
+#  else
+#    include "Widkit/simple_wk_widget.hpp"
+#  endif
 #endif
 #include "server.hpp"
 #include "drd_info.hpp"
 #ifdef EXPERIMENTAL
-#include "../Style/Environment/environment.hpp"
-#include "../Style/Memorizer/memorizer.hpp"
+#  include "../Style/Environment/environment.hpp"
+#  include "../Style/Memorizer/memorizer.hpp"
 #endif
 #include "new_data.hpp"
 #define TEXMACS_COPYRIGHT (string("(c) 1999-2006 by Joris van der Hoeven"))
@@ -40,10 +40,12 @@
 #define THE_LOCUS 128
 
 class tm_buffer_rep;
-typedef tm_buffer_rep* tm_buffer;
 class tm_view_rep;
 class server_rep;
+typedef tm_buffer_rep* tm_buffer;
+typedef tm_view_rep* tm_view;
 class modification;
+class editor;
 extern bool enable_fastenv;
 
 class editor_rep: public simple_widget_rep {
@@ -79,7 +81,7 @@ protected:
   virtual void                 set_init (hashmap<string,tree> H= tree ("?"))=0;
   virtual void                 add_init (hashmap<string,tree> H) = 0;
   virtual void                 set_fin (hashmap<string,tree> H) = 0;
-  virtual void                 set_base_name (url name) = 0;
+  virtual void                 set_master (url name) = 0;
 
   /* exchanging property information */
   virtual void   set_bool_property (string what, bool val) = 0;
@@ -489,7 +491,6 @@ public:
   virtual void search_start (bool forward= true) = 0;
   virtual void search_button_next () = 0;
   virtual bool search_keypress (string s) = 0;
-  virtual tree search_tree () = 0;
   virtual void replace_start (tree what, tree by, bool forward= true) = 0;
   virtual bool replace_keypress (string s) = 0;
   virtual void spell_start () = 0;
@@ -513,6 +514,7 @@ public:
   virtual void export_ps (url ps_name,
 			  string first="1", string last="1000000") = 0;
   virtual array<int> print_snippet (url u, tree t) = 0;
+  virtual bool graphics_file_to_clipboard (url output) = 0;
   virtual void footer_eval (string s) = 0;
   virtual tree the_line () = 0;
   virtual tree the_root () = 0;
@@ -537,8 +539,10 @@ public:
   friend void   edit_done (editor_rep* ed, modification mod);
   friend string get_editor_status_report ();
   friend void   tm_failure (const char* msg);
-  friend void   revert_buffer (url name, tree doc);
-  friend void   set_aux (string aux, url name);
+  friend void   set_buffer_tree (url name, tree doc);
+  friend void   set_master_buffer (url name, url master);
+  friend void   set_current_view (url u);
+  friend void   focus_on_editor (editor ed);
 };
 
 class editor {
@@ -551,11 +555,11 @@ EXTEND_NULL_CODE(widget,editor);
 
 editor new_editor (server_rep* sv, tm_buffer buf);
 
-#define SERVER(cmd) {                    \
-  tm_view temp_vw= sv->get_view (false); \
-  focus_on_this_editor ();               \
-  sv->cmd;                               \
-  sv->set_view (temp_vw);                \
+#define SERVER(cmd) {                 \
+  url temp= get_current_view_safe (); \
+  focus_on_this_editor ();            \
+  sv->cmd;                            \
+  set_current_view (temp);            \
 }
 
 #endif // defined EDITOR_H
