@@ -288,6 +288,7 @@ bib_change_case (string s, string op) {
 
 void
 bib_change_case (tree& t, string (*change_case) (string)) {
+  //cout << "Change case " << t << "\n";
   if (is_atomic (t) && change_case) t->label= change_case (t->label);
   else if (is_compound (t, "verbatim"));
   else if (L(t) == WITH) bib_change_case (t[N(t)-1], change_case);
@@ -863,6 +864,7 @@ bib_set_fields (tree& t, array<tree> latex, int& ind) {
 
 static array<tree>
 bib_latex_array (tree latex) {
+  if (is_func(latex, WITH)) latex= latex[N(latex) - 1];
   int i= 0;
   array<tree> res;
   while (i < N(latex) && latex[i] == compound ("nextbib", "")) {
