@@ -4,10 +4,9 @@
 * DESCRIPTION: resources for true type faces, gliefs and metrics
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #ifndef TT_FACE_H
@@ -50,7 +49,7 @@ struct tt_font_glyphs_rep: font_glyphs_rep {
 
 tt_face load_tt_face (string name);
 font_metric tt_font_metric (string family, int size, int dpi);
-font_glyphs tt_font_glyphs (string family, int size, int dpi);
+//font_glyphs tt_font_glyphs (string family, int size, int dpi);
 
 #endif // USE_FREETYPE
 
