@@ -46,15 +46,20 @@ gs_image_size_sub (string buf, int& w_pt, int& h_pt) {
   if (pos < 0) return false;
   if (buf[pos] == '\n') pos++;
   bool ok= read (buf, pos, "%%BoundingBox: ");
+  double X1, Y1, X2, Y2;
   int x1, y1, x2, y2;
   skip_spaces (buf, pos);
-  ok= ok && read_int (buf, pos, x1);
+  ok= ok && read_double (buf, pos, X1);
+  x1= (int) floor (X1);
   skip_spaces (buf, pos);
-  ok= ok && read_int (buf, pos, y1);
+  ok= ok && read_double (buf, pos, Y1);
+  y1= (int) floor (Y1);
   skip_spaces (buf, pos);
-  ok= ok && read_int (buf, pos, x2);
+  ok= ok && read_double (buf, pos, X2);
+  x2= (int) ceil (X2);
   skip_spaces (buf, pos);
-  ok= ok && read_int (buf, pos, y2);
+  ok= ok && read_double (buf, pos, Y2);
+  y2= (int) ceil (Y2);
   if (!ok) return false;
   w_pt= x2-x1;
   h_pt= y2-y1;
@@ -82,7 +87,7 @@ void ps_bounding_box (url image, int& x1, int& y1, int& x2, int& y2);
 
 static bool
 use_converts (url image) {
-#ifdef __MINGW__
+#if defined(__MINGW__) || defined(__MINGW32__)
   (void) image; return false;
 #else
   // NOTE: determine whether we should use image magick.
