@@ -13,8 +13,6 @@
 #define TEX_FILES_H
 #include "url.hpp"
 
-int    get_font_type ();
-void   set_font_type (int type);
 void   make_tex_tfm (string fn_name);
 void   make_tex_pk (string fn_name, int dpi, int design_dpi);
 void   reset_tfm_path (bool rehash= true);
