@@ -28,6 +28,11 @@
 #include "QTMWidget.hpp"
 #include "QTMWindow.hpp"
 #include "qt_renderer.hpp" // for the_qt_renderer
+#include "file.hpp" // added for copy_as_graphics
+#include <QMimeData>
+#include <QByteArray>
+#include <QApplication>
+#include <QImage>
 
 #ifdef MACOSX_EXTENSIONS
 #include "MacOS/mac_utilities.h"
@@ -230,8 +235,6 @@ void qt_gui_rep::set_mouse_pointer (string curs_name, string mask_name)
 
 void
 qt_gui_rep::show_wait_indicator (widget w, string message, string arg)  {
-  (void) w; (void) message; (void) arg;
-  
   if (DEBUG_QT)  cout << "show_wait_indicator \"" << message << "\"\"" << arg << "\"" << LF;
 
   qt_window_widget_rep *wid = static_cast<qt_window_widget_rep*> (w.rep);
@@ -244,7 +247,7 @@ qt_gui_rep::show_wait_indicator (widget w, string message, string arg)  {
   //FIXME: we must center the wait widget wrt the current active window
   
   if (!waitWindow) {
-    waitWindow = new QWidget (wid->wid->window());
+    waitWindow = new QWidget (wid->qwid->window());
     waitWindow->setWindowFlags (Qt::Window | Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint);
     QStackedLayout *layout = new QStackedLayout();
     layout->setSizeConstraint(QLayout::SetFixedSize);
@@ -283,7 +286,7 @@ qt_gui_rep::show_wait_indicator (widget w, string message, string arg)  {
       // processEvents is needed to let Qt update windows coordinates in the case
       qApp->processEvents();
       //ENDHACK
-      QPoint pt = wid->wid->window()->geometry().center();
+      QPoint pt = wid->qwid->window()->geometry().center();
       rect.moveCenter(pt);
       waitWindow->move(rect.topLeft());
       
@@ -503,7 +506,7 @@ gui_maximal_extents (SI& width, SI& height) {
 void
 gui_refresh () {
   // called upon change of output language
-  // emit a signal which force every QTMAction to change his text
+  // emit a signal which forces every QTMAction to change his text
   // according to the new language
 
   the_gui->gui_helper->doRefresh();
@@ -527,17 +530,17 @@ QTMGuiHelper::doRefresh () {
 
 bool
 QTMGuiHelper::eventFilter (QObject *obj, QEvent *event) {
-   if (event->type() == QEvent::FileOpen) {
-     QFileOpenEvent *openEvent = static_cast<QFileOpenEvent *>(event);
-     const char *s = openEvent->file().toAscii().constData();
-     //qDebug ("File Open Event %s", s);
-     call ( "texmacs-load-buffer", object(url_system (s)), 
-            object("generic"), object(1), object(false));
-     return true;
-   } else {
-     // standard event processing
-     return QObject::eventFilter(obj, event);
-   }
+  if (event->type() == QEvent::FileOpen) {
+    QFileOpenEvent *openEvent = static_cast<QFileOpenEvent *>(event);
+    const char *s = openEvent->file().toAscii().constData();
+    //qDebug ("File Open Event %s", s);
+    call ("load-buffer", object (url_system (s)), eval (":new-window"));
+    return true;
+  }
+  else {
+    // standard event processing
+    return QObject::eventFilter(obj, event);
+  }
 }
 
 void
@@ -755,38 +758,58 @@ add_event(const queued_event &ev)
 }
 
 void 
-qt_gui_rep::process_keypress (simple_widget_rep *wid, string key, time_t t) {
+qt_gui_rep::process_keypress (qt_simple_widget_rep *wid, string key, time_t t) {
   typedef triple<widget, string, time_t > T;
+  if (wid->type != qt_widget_rep::simple_widget) {
+    if (DEBUG_QT)
+      cout << "WTF! Situation] process_keypress() for non simple_widget.\n";
+    return;
+  }
   add_event( queued_event ( QP_KEYPRESS, close_box<T> (T(wid, key, t)))); 
  // wid -> handle_keypress (key, t);
  // needs_update ();
 }
 
 void 
-qt_gui_rep::process_keyboard_focus ( simple_widget_rep *wid, bool has_focus, 
+qt_gui_rep::process_keyboard_focus (qt_simple_widget_rep *wid, bool has_focus, 
                                      time_t t ) {
   typedef triple<widget, bool, time_t > T;
+  if (wid->type != qt_widget_rep::simple_widget) {
+    if (DEBUG_QT)
+      cout << "WTF! Situation] process_keyboard_focus() for non simple_widget.\n";
+    return;
+  }
   add_event( 
-    queued_event ( QP_KEYBOARD_FOCUS, close_box<T> (T(wid, has_focus, t)))); 
+    queued_event (QP_KEYBOARD_FOCUS, close_box<T> (T(wid, has_focus, t)))); 
   //wid -> handle_keyboard_focus (has_focus, t);
   //needs_update ();
 }
 
 void 
-qt_gui_rep::process_mouse ( simple_widget_rep *wid, string kind, SI x, SI y, 
+qt_gui_rep::process_mouse (qt_simple_widget_rep *wid, string kind, SI x, SI y, 
                             int mods, time_t t ) {
   typedef quintuple<string, SI, SI, int, time_t > T1;
   typedef pair<widget, T1> T;
+  if (wid->type != qt_widget_rep::simple_widget) {
+    if (DEBUG_QT)
+      cout << "WTF! Situation] process_mouse() for non simple_widget.\n"; 
+    return;
+  }
   add_event ( 
-    queued_event ( QP_MOUSE, close_box<T> ( T (wid, T1 (kind, x, y, mods, t))))); 
+    queued_event (QP_MOUSE, close_box<T> ( T (wid, T1 (kind, x, y, mods, t))))); 
 //  wid -> handle_mouse (kind, x, y, mods, t);
 //  needs_update ();
 }
 
 void 
-qt_gui_rep::process_resize ( simple_widget_rep *wid, SI x, SI y ) {
+qt_gui_rep::process_resize (qt_simple_widget_rep *wid, SI x, SI y ) {
   typedef triple<widget, SI, SI > T;
-  add_event(  queued_event ( QP_RESIZE, close_box<T> (T(wid, x, y)))); 
+  if (wid->type != qt_widget_rep::simple_widget) {
+    if (DEBUG_QT)
+      cout << "WTF! Situation] process_resize() for non simple_widget.\n";    
+    return;
+  }
+  add_event( queued_event ( QP_RESIZE, close_box<T> (T(wid, x, y)))); 
 //  wid -> handle_notify_resize (x, y);
 //  needs_update ();
 }
@@ -940,12 +963,12 @@ qt_gui_rep::update () {
     QSetIterator<QTMWidget*> i(QTMWidget::all_widgets);
     while (i.hasNext()) {
       QTMWidget *w = i.next();
-      w->repaint_invalid_regions();
+      if (w->isVisible())
+        w->repaint_invalid_regions();
     }
     //cout << "AND END" << LF;
   }
   
-  
   if (N(waiting_events) > 0) needing_update = true;
   if (interrupted) needing_update = true;
  // if (interrupted)     cout << "*";
@@ -972,7 +995,24 @@ qt_gui_rep::update () {
   //        The interval cannot be too small to keep CPU usage low in idle state
 } 
 
-
+/*
+ FIXME: implement fade out of popup after mouse out events, etc.
+ Maybe use a dedicated wrapper QWidget which handles events, giving it the
+ focus and which releases it as soon as some key is pressed or the mouse is
+ moved out of it (problem: the widget need not appear below the mouse pointer,
+ thus making it impossible to access links or widgets inside it.
+ Solution?: as soon as the mouse moves (out of the widget), start a timer, 
+ giving enough time to the user to move (back) into the widget, then abort the
+ close operation if he gets there.
+ */
+void
+qt_gui_rep::show_help_balloon (widget wid, SI x, SI y) {
+  popup_wid= popup_widget (wid);
+  popup_win= popup_window_widget(popup_wid, "Balloon");
+  set_position (popup_win, x, y);
+  set_visibility(popup_win, true);
+    //send_mouse_grab(popup_win, true);
+}
 
 /******************************************************************************
 * Font support
@@ -1031,6 +1071,40 @@ clear_selection (string key) {
   the_gui->clear_selection (key);
 }
 
+bool
+qt_gui_rep::put_graphics_on_clipboard (url file) {
+   string extension= suffix (file) ;
+   
+  // for bitmaps this works :
+  if ((extension == "bmp") || (extension == "png") ||
+      (extension == "jpg") || (extension == "jpeg")) { 
+    QImage myqimage=QImage ( as_charp (as_string (file)) );
+    QClipboard *clipboard = QApplication::clipboard();
+    clipboard->setImage(myqimage);
+  }
+  else {
+    // vector formats
+    // Are there applications receiving eps, pdf,... through the clipboard?
+    // I have not experimented with EMF/WMF (windows) or SVM (Ooo)
+    QString mime="image/*"; // generic image format;
+    if (extension == "eps") mime= "application/postscript";
+    if (extension == "pdf") mime= "application/pdf";
+    if (extension == "svg") mime= "image/svg+xml"; //this works with Inskcape version >= 0.47
+   
+    string filecontent;
+    load_string (as_string (file), filecontent, true);
+
+    QByteArray rawdata= as_charp (filecontent);
+
+    QMimeData *mymimeData = new QMimeData;
+    mymimeData->setData(mime, rawdata);
+
+    QClipboard *clipboard = QApplication::clipboard();
+    clipboard->setMimeData(mymimeData);// default mode= QClipboard::Clipboard 
+  }
+  return true;
+}
+
 /******************************************************************************
 * Miscellaneous
 ******************************************************************************/
@@ -1082,7 +1156,7 @@ void
 show_help_balloon (widget balloon, SI x, SI y) {
   // Display a help balloon at position (x, y); the help balloon should
   // disappear as soon as the user presses a key or moves the mouse
-  (void) balloon; (void) x; (void) y;
+  the_gui->show_help_balloon(balloon, x, y);
 }
 
 void
@@ -1091,7 +1165,7 @@ show_wait_indicator (widget base, string message, string argument) {
   // The indicator might for instance be displayed at the center of
   // the base widget which triggered the lengthy operation;
   // the indicator should be removed if the message is empty
-  the_gui->show_wait_indicator(base,message,argument);
+  the_gui->show_wait_indicator(base, message, argument);
 }
 
 void
@@ -1099,7 +1173,7 @@ external_event (string type, time_t t) {
   // External events, such as pushing a button of a remote infrared commander
   QTMWidget *tm_focus = qobject_cast<QTMWidget*>(qApp->focusWidget());
   if (tm_focus) {
-    simple_widget_rep *wid = tm_focus->tm_widget();
+    simple_widget_rep* wid = tm_focus->tm_widget();
     if (wid) the_gui -> process_keypress (wid, type, t);
   }
 }
