@@ -1,7 +1,7 @@
 
 /******************************************************************************
  * MODULE     : qt_tm_widget.hpp
- * DESCRIPTION: The main TeXmacs widget for the Qt GUI
+ * DESCRIPTION: The main TeXmacs input widget and its embedded counterpart.
  * COPYRIGHT  : (C) 2008  Massimiliano Gubinelli
  *******************************************************************************
  * This software falls under the GNU general public license version 3 or later.
@@ -25,14 +25,15 @@
 #include <QStackedWidget>
 #include <QLayout>
 
-class QLabel; class QToolBar;
+class QLabel; 
+class QToolBar;
 class QTMInteractivePrompt;
 
-/**
- * Main TeXmacs' widget. This is the interface between TeXmacs
- * and our QT implementation of this widget. The auxiliary function 
- * texmacs_widget() returns an instance of this class to be used within 
- * the rest of TeXmacs.
+/*! Models one main window with toolbars, an associated view, etc.
+ 
+ The underlying QWidget is a QTMWindow, whose central widget is a 
+ QStackedWidget holding the canvases for all the open buffers. Each canvas
+ is of type QTMWidget and belongs to one qt_simple_widget_rep.
  */
 class qt_tm_widget_rep: public qt_view_widget_rep {
 public: 
@@ -43,6 +44,7 @@ public:
   QToolBar *modeToolBar;
   QToolBar *focusToolBar;
   QToolBar *userToolBar;
+  QToolBar *sideToolBar;
   
 
 #ifdef Q_WS_MAC
@@ -54,17 +56,14 @@ public:
   QWidget *rulerWidget;
 #endif
   
-  
   QWidget *centralWidget;
   
   QTMInteractiveInputHelper helper;
-  
   QTMInteractivePrompt *prompt;
-  
   qt_widget int_prompt;
   qt_widget int_input;
   
-  bool visibility[6];
+  bool visibility[7];
   bool full_screen;
   
   command quit;
@@ -74,43 +73,74 @@ public:
   widget mode_icons_widget;
   widget focus_icons_widget;
   widget user_icons_widget;
+  widget side_tools_widget;
   widget waiting_main_menu_widget;
   
 public:
   qt_tm_widget_rep (int mask, command _quit);
   ~qt_tm_widget_rep ();
   
-  virtual void send (slot s, blackbox val);
+  virtual widget plain_window_widget (string title, command quit);
+
+  virtual void      send (slot s, blackbox val);
   virtual blackbox query (slot s, int type_id);
-  virtual widget read (slot s, blackbox index);
-  virtual void write (slot s, blackbox index, widget w);
-  
-  virtual widget plain_window_widget (string s, command q);
-  
-  QMainWindow* tm_mainwindow () {
-    return qobject_cast<QMainWindow*> (view); }
-  QStackedWidget* tm_centralwidget () {
-    return tm_mainwindow()->findChild<QStackedWidget*>("stacked widget"); }
-  QTMScrollView* tm_scrollarea () {
-    return qobject_cast<QTMScrollView*> (tm_centralwidget()->currentWidget()); }
-  QTMWidget* tm_canvas () {
-    return qobject_cast<QTMWidget*> (tm_scrollarea()); }
-  
+  virtual widget    read (slot s, blackbox index);
+  virtual void     write (slot s, blackbox index, widget w);
+    
+  void set_full_screen (bool flag);
   void updateVisibility();
   void install_main_menu ();
-  void set_full_screen (bool flag);
+
+    ////// Convenience methods to access our QWidgets
+protected:
+  QMainWindow* mainwindow () {
+    return qobject_cast<QMainWindow*> (qwid); 
+  }
+  QStackedWidget* centralwidget () {
+    return qwid->findChild<QStackedWidget*>("stacked widget");
+  }
+  QTMScrollView* scrollarea () {
+    return qobject_cast<QTMScrollView*> (centralwidget()->currentWidget());
+  }
+  QTMWidget* canvas () {
+    return qobject_cast<QTMWidget*> (scrollarea());
+  }
 };
 
 
-/**
- * List of widgets wanting to install their menu bar
- */
+//! List of widgets wanting to install their menu bar
 extern list<qt_tm_widget_rep*> waiting_widgets;
 
-/**
- * Positive means the menu is busy.
- */
+//! Positive means the menu is busy.
 extern int menu_count;
 
 
+/*! A simple texmacs input widget.
+ 
+ This is a stripped down version of qt_tm_widget_rep, whose underlying widget
+ isn't a QTMWindow anymore, but a regular QWidget (right now a QStackedWidget)
+ because it is intended to be embedded into a window.
+ 
+ FIXME: the QStackedWidget is not needed for embedded texmacs widgets.
+*/
+class qt_tm_embedded_widget_rep: public qt_view_widget_rep {
+public:
+  command quit;
+  
+  qt_tm_embedded_widget_rep (command _quit);
+  ~qt_tm_embedded_widget_rep ();
+
+  virtual void      send (slot s, blackbox val);
+  virtual blackbox query (slot s, int type_id);
+  virtual void     write (slot s, blackbox index, widget w);
+  
+protected:
+  QTMScrollView* scrollarea () {
+    return qobject_cast<QTMScrollView*> (qwid);
+  }
+  QTMWidget* canvas () {
+    return qobject_cast<QTMWidget*> (scrollarea());
+  }
+};
+
 #endif // QT_TM_WIDGET_HPP
