@@ -32,6 +32,7 @@
   (tm-errput tm_errput (void string))
   (win32-display win32_display (void string))
   (cpp-error cpp_error (void))
+  (rescue-mode? in_rescue_mode (bool))
   (scheme-dialect scheme_dialect (string))
   (get-texmacs-path get_texmacs_path (string))
   (plugin-list plugin_list (scheme_tree))
@@ -122,6 +123,9 @@
   (tree-empty? is_empty (bool content))
   (tree-is-buffer? admits_edit_observer (bool tree))
   (tree-search-sections search_sections (array_tree tree))
+  (tag-minimal-arity minimal_arity (int tree_label))
+  (tag-maximal-arity maximal_arity (int tree_label))
+  (tag-possible-arity? correct_arity (bool tree_label int))
 
   (tree-assign tree_assign (tree tree content))
   (tree-var-insert tree_insert (tree tree int content))
@@ -215,6 +219,7 @@
   (escape-generic escape_generic (string string))
   (escape-verbatim escape_verbatim (string string))
   (escape-shell escape_sh (string string))
+  (escape-to-ascii cork_to_ascii (string string))
   (string-convert convert (string string string string))
   (utf8->cork utf8_to_cork (string string))
   (cork->utf8 cork_to_utf8 (string string))
@@ -271,24 +276,35 @@
   (upgrade-mathml upgrade_mathml (tree content))
 
   ;; routines for urls
+  (url->url url (url url))
+  (root->url url_root (url string))
   (string->url url (url string))
-  (url url (url string string))
-  (url-system url_system (url string))
+  (url->string as_string (string url))
+  (system->url url_system (url string))
+  (url->system as_system_string (string url))
+  (unix->url url_unix (url string))
+  (url->unix as_unix_string (string url))
+  (url-unix url (url string string))
   (url-none url_none (url))
   (url-any url_wildcard (url))
   (url-wildcard url_wildcard (url string))
+  (url-pwd url_pwd (url))
   (url-parent url_parent (url))
   (url-ancestor url_ancestor (url))
   (url-append url_concat (url url url))
   (url-or url_or (url url url))
-  (url->string as_string (string url))
   (url-none? is_none (bool url))
+  (url-rooted? is_rooted (bool url))
   (url-rooted-web? is_rooted_web (bool url))
+  (url-rooted-tmfs? is_rooted_tmfs (bool url))
+  (url-root get_root (string url))
+  (url-unroot unroot (url url))
   (url-concat? is_concat (bool url))
   (url-or? is_or (bool url))
   (url-ref url_ref (url url int))
   (url-head head (url url))
   (url-tail tail (url url))
+  (url-format file_format (string url))
   (url-suffix suffix (string url))
   (url-glue glue (url url string))
   (url-unglue unglue (url url int))
@@ -316,6 +332,7 @@
   (url-temp url_temp (url))
   (url-scratch url_scratch (url string string int))
   (url-scratch? is_scratch (bool url))
+  (url-cache-invalidate web_cache_invalidate (void url))
   (string-save string_save (void string url))
   (string-load string_load (string url))
   (system-move move (void url url))
@@ -326,6 +343,12 @@
   (system-1 system (void string url))
   (system-2 system (void string url url))
 
+  (persistent-set persistent_set (void url string string))
+  (persistent-remove persistent_reset (void url string))
+  (persistent-has? persistent_contains (bool url string))
+  (persistent-get persistent_get (string url string))
+  (persistent-file-name persistent_file_name (url url string))
+  
   ;; TeXmacs file system
   (tmfs-set tmfs_set (void string collection))
   (tmfs-reset tmfs_reset (void string collection))
@@ -439,37 +462,62 @@
   (get-remove-package-menu get_remove_package_menu (object))
 
   ;; buffers
-  (this-buffer get_this_buffer (url))
-  (all-buffers get_all_buffers (url))
-  (path->buffer get_name_buffer (url path))
-  (set-name-buffer set_name_buffer (void url))
-  (get-name-buffer get_name_buffer (url))
-  (buffer-set-short-name set_abbr_buffer (void url string))
-  (buffer-get-short-name get_abbr_buffer (string url))
-  (buffer-modified? buffer_modified (bool url))
-  (buffer-in-menu? buffer_in_menu (bool url))
+  (buffer-list get_all_buffers (array_url))
+  (current-buffer-url get_current_buffer_safe (url))
+  (path-to-buffer path_to_buffer (url path))
+  (buffer-new make_new_buffer (url))
+  (buffer-rename rename_buffer (void url url))
+  (buffer-set set_buffer_tree (void url content))
+  (buffer-get get_buffer_tree (tree url))
+  (buffer-set-body set_buffer_body (void url content))
+  (buffer-get-body get_buffer_body (tree url))
+  (buffer-set-master set_master_buffer (void url url))
+  (buffer-get-master get_master_buffer (url url))
+  (buffer-set-title set_title_buffer (void url string))
+  (buffer-get-title get_title_buffer (string url))
+  (buffer-last-save get_last_save_buffer (int url))
   (buffer-last-visited last_visited (double url))
-  (buffer-set-tree set_buffer_tree (void url content))
-  (buffer-get-tree get_buffer_tree (tree url))
-  (buffer-revert-tree revert_buffer (void url content))
+  (buffer-modified? buffer_modified (bool url))
+  (buffer-modified-since-autosave? buffer_modified_since_autosave (bool url))
+  (buffer-pretend-modified pretend_buffer_modified (void url))
+  (buffer-pretend-saved pretend_buffer_saved (void url))
+  (buffer-pretend-autosaved pretend_buffer_autosaved (void url))
+  (buffer-has-name? buffer_has_name (bool url))
+  (buffer-aux? is_aux_buffer (bool url))
+  (buffer-import buffer_import (bool url url string))
+  (buffer-load buffer_load (bool url))
+  (buffer-export buffer_export (bool url url string))
+  (buffer-save buffer_save (bool url))
+  (tree-import import_tree (tree url string))
+  (tree-export export_tree (bool tree url string))
+
+  (view-list get_all_views (array_url))
+  (buffer->views buffer_to_views (array_url url))
+  (current-view-url get_current_view_safe (url))
+  (window->view window_to_view (url url))
+  (view->buffer view_to_buffer (url url))
+  (view->window-url view_to_window (url url))
+  (view-new get_new_view (url url))
+  (view-passive get_passive_view (url url))
+  (view-recent get_recent_view (url url))
+  (view-delete delete_view (void url))
+  (window-set-view window_set_view (void url url bool))
+  (switch-to-buffer switch_to_buffer (void url))
+
+  (window-list windows_list (array_url))
+  (windows-number get_nr_windows (int))
+  (current-window get_current_window (url))
+  (buffer->windows buffer_to_windows (array_url url))
+  (window-to-buffer window_to_buffer (url url))
+  (window-set-buffer window_set_buffer (void url url))
+  (window-focus window_focus (void url))
 
   (new-buffer create_buffer (url))
-  (switch-to-buffer-path switch_to_buffer (bool path))
-  (switch-to-buffer switch_to_buffer (void url))
-  (switch-to-active-buffer switch_to_active_buffer (void url))
-  (revert-buffer revert_buffer (void))
-  (kill-buffer kill_buffer (void))
-  (no-name? no_name (bool))
-  (help-buffer? help_buffer (bool))
-  (aux-buffer? is_aux_buffer (bool url))
-  (set-aux set_aux (void string url))
-  (set-aux-buffer set_aux_buffer (void string url content))
-  (set-help-buffer set_help_buffer (void url content))
-
   (open-buffer-in-window new_buffer_in_new_window (void url content content))
   (open-window open_window (url))
   (open-window-geometry open_window (url content))
   (clone-window clone_window (void))
+  (buffer-close kill_buffer (void url))
   (kill-window kill_window (void))
   (kill-window-and-buffer kill_window_and_buffer (void))
 
@@ -478,28 +526,13 @@
   (project-attached? project_attached (bool))
   (project-get project_get (url))
 
-  (window-current window_current (int))
-  (window-list windows_list (path))
-  (buffer->windows buffer_to_windows (path url))
-  (window->buffer window_to_buffer (url int))
-  (window-set-buffer window_set_buffer (void int url))
-  (window-focus window_focus (void int))
-
-  (pretend-save-buffer pretend_save_buffer (void))
-  (buffer-unsaved? buffer_unsaved (bool))
-  (exists-unsaved-buffer? exists_unsaved_buffer (bool))
-  (texmacs-load-tree load_tree (tree url string))
-  (texmacs-load-buffer load_buffer (void url string int bool))
-  (texmacs-save-buffer save_buffer (void url string))
-  (auto-save auto_save (void))
-
-  ;; windows
-  (window-handle window_handle (int))
-  (window-create window_create (void int widget string bool))
-  (window-create-quit window_create (void int widget string command))
-  (window-delete window_delete (void int))
-  (window-show window_show (void int))
-  (window-hide window_hide (void int))
+  ;; transitional alternative windows; to be replaced by better solution
+  (alt-window-handle window_handle (int))
+  (alt-window-create window_create (void int widget string bool))
+  (alt-window-create-quit window_create (void int widget string command))
+  (alt-window-delete window_delete (void int))
+  (alt-window-show window_show (void int))
+  (alt-window-hide window_hide (void int))
 
   ;; routines for BibTeX
   (bib-add-period bib_add_period (scheme_tree scheme_tree))
@@ -514,5 +547,3 @@
   (bib-field bib_field (scheme_tree scheme_tree string))
   (bib-abbreviate bib_abbreviate
 		  (scheme_tree scheme_tree scheme_tree scheme_tree)))
-
-
