@@ -89,7 +89,7 @@ cpp_error () {
 
 array<int>
 get_bounding_rectangle (tree t) {
-  editor ed= get_server () -> get_editor ();
+  editor ed= get_current_editor ();
   rectangle wr= ed -> get_window_extents ();
   path p= reverse (obtain_ip (t));
   selection sel= ed->search_selection (p * 0, p * right_index (t));
@@ -669,6 +669,7 @@ TMSCM_ASSERT (tmscm_is_solution(p), p, arg, rout)
 typedef array<int> array_int;
 typedef array<string> array_string;
 typedef array<tree> array_tree;
+typedef array<url> array_url;
 typedef array<widget> array_widget;
 typedef array<double> array_double;
 typedef array<array<double> > array_array_double;
@@ -888,6 +889,35 @@ tmscm_to_array_widget (tmscm  p) {
   return a;
 }
 
+static bool
+tmscm_is_array_url (tmscm  p) {
+  if (tmscm_is_null (p)) return true;
+  else return tmscm_is_pair (p) &&
+    tmscm_is_url (tmscm_car (p)) &&
+    tmscm_is_array_url (tmscm_cdr (p));
+}
+
+#define TMSCM_ASSERT_ARRAY_URL(p,arg,rout) \
+TMSCM_ASSERT (tmscm_is_array_url (p), p, arg, rout)
+
+/* static */ tmscm 
+array_url_to_tmscm (array<url> a) {
+  int i, n= N(a);
+  tmscm  p= tmscm_null ();
+  for (i=n-1; i>=0; i--) p= tmscm_cons (url_to_tmscm (a[i]), p);
+  return p;
+}
+
+/* static */ array<url>
+tmscm_to_array_url (tmscm  p) {
+  array<url> a;
+  while (!tmscm_is_null (p)) {
+    a << tmscm_to_url (tmscm_car (p));
+    p= tmscm_cdr (p);
+  }
+  return a;
+}
+
 static bool
 tmscm_is_properties (tmscm  p) {
   if (tmscm_is_null (p)) return true;
@@ -1032,6 +1062,7 @@ tmscm_to_collection (tmscm  p) {
 #include "convert.hpp"
 #include "file.hpp"
 #include "image_files.hpp"
+#include "web_files.hpp"
 #include "sys_utils.hpp"
 #include "tmfs.hpp"
 #include "client_server.hpp"
@@ -1053,6 +1084,7 @@ tmscm_to_collection (tmscm  p) {
 #include "patch.hpp"
 #include "packrat.hpp"
 #include "new_style.hpp"
+#include "persistent.hpp"
 
 #include "../Glue/glue_basic.cpp"
 #include "../Glue/glue_editor.cpp"
