@@ -148,6 +148,12 @@ url_default (string name, int type= URL_SYSTEM) {
 #endif
 }
 
+static url
+url_mingw_default (string name, int type) {
+  string s= name (0, 2) * ":" * name (2, N(name));
+  return url_root ("default") * url_get_name (s, type);  
+}
+
 static url
 url_path (string s, int type= URL_SYSTEM) {
   url u= url_get_path (s, type);
@@ -230,6 +236,17 @@ heuristic_is_ftp (string name) {
   return starts (name, "ftp.");
 }
 
+static bool
+heuristic_is_mingw_default (string name, int type) {
+#ifdef WINPATHS
+  return type != URL_SYSTEM && N(name) >= 2 &&
+         name[0] == '/' && is_alpha (name[1]) &&
+         (N(name) == 2 || name[2] == '/');
+#else
+  (void) name; (void) type; return false;
+#endif         
+}
+
 url
 url_general (string name, int type= URL_SYSTEM) {
   if (starts (name, "local:")) return url_local (name (6, N (name)));
@@ -240,6 +257,7 @@ url_general (string name, int type= URL_SYSTEM) {
   if (starts (name, "//")) return url_blank (name (2, N (name)));
   if (heuristic_is_path (name, type)) return url_path (name, type);
   if (heuristic_is_default (name, type)) return url_default (name, type);
+  if (heuristic_is_mingw_default (name, type)) return url_mingw_default (name, type);
   if (heuristic_is_http (name)) return url_http (name);
   if (heuristic_is_ftp (name)) return url_ftp (name);
   return url_get_name (name, type);
@@ -275,6 +293,7 @@ url_standard (string dir, string name) {
   return url_standard (dir) * url_standard (name);
 }
 
+url::url (): rep (tm_new<url_rep> (tuple ("none"))) {}
 url::url (const char* name): rep (tm_new<url_rep> (url_unix (name)->t)) {}
 url::url (string name): rep (tm_new<url_rep> (url_unix (name)->t)) {}
 url::url (string path_name, string name):
@@ -284,14 +303,19 @@ url::url (string path_name, string name):
 * Computational url constructors
 ******************************************************************************/
 
+static bool
+is_special_root (url u) {
+#ifdef WINPATHS
+  return is_root (u);
+#else
+  return is_root_web (u);
+#endif
+}
+
 static bool
 is_semi_root (url u) {
   // url u such that u/.. == u (website or windows drive name)
-#ifdef WINPATHS
-  return is_concat (u) && is_root (u[1]) && is_atomic (u[2]);
-#else
-  return is_concat (u) && is_root_web (u[1]) && is_atomic (u[2]);
-#endif
+  return is_concat (u) && is_special_root (u[1]) && is_atomic (u[2]);
 }
 
 url
@@ -462,10 +486,19 @@ as_string (url u, int type) {
       s2= "{" * s2 * "}";
 #ifdef WINPATHS
     if (is_semi_root (u)) {
-      if (ends (s2, ":")) return s2 * "\\";
-      else return s2;
+      if (ends (s2, ":")) {
+        if (type == URL_SYSTEM) return s2 * "\\";
+        else return s1 * sep * s2 (0, N(s2) - 1);
+      }
+      else {
+        if (type == URL_SYSTEM) return s2;
+        else return s1 * sep * s2;
+      }
     }
-    if (is_root (u[1]) && stype == URL_SYSTEM) return s2;
+    if (is_root (u[1]) && type != URL_SYSTEM && N(s2) >= 2 && is_alpha (s2[0]) && s2[1] == ':')
+      return s1 * sep * s2 (0, 1) * s2 (2, N(s2));
+    if (is_root (u[1]) && stype == URL_SYSTEM)
+      return s2;
 #endif
     return s1 * sep * s2;
   }
@@ -578,16 +611,16 @@ relative (url base, url u) {
 
 url
 delta_sub (url base, url u) {
-#ifdef WINPATHS
-  if (is_atomic (base) || heuristic_is_default (as_string (base), URL_SYSTEM))
-    return u;
-#else
   if (is_atomic (base))
     return u;
-#endif
-  if (is_concat (base) && is_concat (u) && (base[1] == u[1]))
+  if (is_concat (base) && is_concat (u) && (base[1] == u[1])) {
+    if (is_special_root (base[1]) &&
+	is_concat (base[2]) && is_concat (u[2]) &&
+	base[2][1] != u[2][1])
+      return url_none ();
     return delta_sub (base[2], u[2]);
-  if (is_concat (base))
+  }
+  if (is_concat (base) && !is_semi_root (base))
     return url_parent () * delta_sub (head (base), u);
   return url_none ();
 }
@@ -607,6 +640,7 @@ expand (url u1, url u2) {
   if (is_or (u2)) return expand (u1, u2[1]) | expand (u1, u2[2]);
   if (is_ancestor (u2)) {
     if (is_concat (u1)) return u1 | expand (u1[1], u2);
+    if (is_special_root (u1)) return u2;
     return u1 | u2;
   }
   if (is_concat (u2) && is_ancestor (u2[1]))
@@ -703,6 +737,26 @@ factor (url u) {
 
 url complete (url base, url u, string filter, bool flag);
 
+string
+get_root (url u) {
+  if (is_concat (u)) return get_root (u[1]);
+  if (is_or (u)) {
+    string s1= get_root (u[1]);
+    string s2= get_root (u[2]);
+    if (s1 == s2) return s1; else return "";
+  }
+  if (is_root (u)) return u[1]->t->label;
+  return "";
+}
+
+url
+unroot (url u) {
+  if (is_concat (u)) return unroot (u[1]) * u[2];
+  if (is_or (u)) return unroot (u[1]) | unroot (u[2]);
+  if (is_root (u)) return url_here ();
+  return u;
+}
+
 url
 reroot (url u, string protocol) {
   if (is_concat (u)) return reroot (u[1], protocol) * u[2];
@@ -727,7 +781,7 @@ complete (url base, url sub, url u, string filter, bool flag) {
 
 url
 complete (url base, url u, string filter, bool flag) {
- // cout << "complete " << base << " |||| " << u << LF;
+  // cout << "complete " << base << " |||| " << u << LF;
   if (is_none (base)) return base;
   if (is_none (u)) return u;
   if ((!is_root (base)) && (!is_rooted_name (base))) {
@@ -745,6 +799,7 @@ complete (url base, url u, string filter, bool flag) {
       return url_none ();
     }
     cerr << LF << "base= " << base << LF;
+    cerr << "u= " << u << LF;
     ASSERT (is_rooted (comp), "unrooted url");
     FAILED ("bad protocol in url");
   }
@@ -799,7 +854,9 @@ complete (url u, string filter) {
   // This routine can be used in order to find all possible matches
   // for the wildcards in an url and replace the wildcards by these matches.
   // Moreover, matches are normalized (file root -> default root).
-  return complete (u, filter, false);
+  url r =  complete (u, filter, false);
+  // cout << "complete:" << u << " filter:" << filter << " result:" << r << LF;
+  return r;
 }
 
 url
