@@ -111,6 +111,8 @@ mathemagix_color_setup_keywords (hashmap<string, string> & t)  {
   t ("debugger")= c;
   t ("destructor")= c;
   t ("direct")= c;
+  t ("disjunction")= c;
+  t ("dispatch")= c;
   t ("div")= c;
   t ("do")= c;
   t ("downto")= c;
@@ -118,6 +120,7 @@ mathemagix_color_setup_keywords (hashmap<string, string> & t)  {
   t ("else")= c;
   t ("evolutive")= c;
   t ("exists")= d;
+  t ("explicit")= c;
   t ("explode")= c;
   t ("export")= d;
   t ("extend")= c;
@@ -134,6 +137,7 @@ mathemagix_color_setup_keywords (hashmap<string, string> & t)  {
   t ("hidden")= c;
   t ("holds")= c;
   t ("if")= c;
+  t ("implicit")= c;
   t ("import")= c;
   t ("in")= c;
   t ("include")= c;
@@ -156,6 +160,7 @@ mathemagix_color_setup_keywords (hashmap<string, string> & t)  {
   t ("loop")= c;
   t ("macro")= c;
   t ("map")= c;
+  t ("match")= c;
   t ("melt")= c;
   t ("method")= c;
   t ("mod")= c;
@@ -164,6 +169,7 @@ mathemagix_color_setup_keywords (hashmap<string, string> & t)  {
   t ("operator")= c;
   t ("or")= c;
   t ("packed")= c;
+  t ("pattern")= c;
   t ("penalty")= c;
   t ("postfix")= "postfix";
   t ("prefer")= c;
@@ -181,6 +187,7 @@ mathemagix_color_setup_keywords (hashmap<string, string> & t)  {
   t ("sequel")= c;
   t ("split")= c;
   t ("step")= c;
+  t ("structure")= e;
   t ("supports?")= c;
   t ("then")= c;
   t ("this")= c;
