@@ -67,7 +67,7 @@ in_presentation_mode () {
 
 tree
 get_subtree (path p) {
-  return get_server()->get_editor()->the_subtree (p);
+  return get_current_editor () -> the_subtree (p);
 }
 
 void
@@ -80,7 +80,7 @@ gui_set_output_language (string lan) {
 server_rep::server_rep () {}
 server_rep::~server_rep () {}
 
-tm_server_rep::tm_server_rep (): vw (NULL), def_sfactor (5) {
+tm_server_rep::tm_server_rep (): def_sfactor (5) {
   the_server= tm_new<server> (this);
   initialize_scheme ();
   gui_interpose (texmacs_interpose_handler);
@@ -106,63 +106,7 @@ tm_server_rep::tm_server_rep (): vw (NULL), def_sfactor (5) {
 
 tm_server_rep::~tm_server_rep () {}
 server::server (): rep (tm_new<tm_server_rep> ()) {}
-
-/******************************************************************************
-* Get and set objects associated to server
-******************************************************************************/
-
-server_rep*
-tm_server_rep::get_server () {
-  return this;
-}
-
-bool
-tm_server_rep::has_view () {
-  return vw != NULL;
-}
-
-bool
-tm_server_rep::has_window () {
-  return vw != NULL && vw->win != NULL;
-}
-
-tm_view
-tm_server_rep::get_view (bool must_be_valid) {
-  ASSERT (!must_be_valid || vw != NULL, "no active view");
-  return vw;
-}
-
-void
-tm_server_rep::set_view (tm_view vw2) {
-  vw= vw2;
-  if (vw != NULL)
-    the_drd= vw->ed->drd;
-}
-
-tm_buffer
-tm_server_rep::get_buffer () {
-  tm_view vw= get_view ();
-  return vw->buf;
-}
-
-editor
-tm_server_rep::get_editor () {
-  tm_view vw= get_view ();
-  // cout << "Get editor" << vw->ed << "\n";
-  return vw->ed;
-}
-
-tm_window
-tm_server_rep::get_window () {
-  tm_view vw= get_view ();
-  ASSERT (vw->win != NULL, "no window attached to view");
-  return vw->win;
-}
-
-int
-tm_server_rep::get_nr_windows () {
-  return nr_windows;
-}
+server_rep* tm_server_rep::get_server () { return this; }
 
 /******************************************************************************
 * Miscellaneous routines
@@ -172,23 +116,18 @@ void
 tm_server_rep::style_clear_cache () {
   style_invalidate_cache ();
 
-  int i, j, n= N(bufs);
-  for (i=0; i<n; i++) {
-    tm_buffer buf= ((tm_buffer) bufs[i]);
-    for (j=0; j<N(buf->vws); j++)
-      ((tm_view) (buf->vws[j]))->ed->init_style ();
-  }
+  array<url> vs= get_all_views ();
+  for (int i=0; i<N(vs); i++)
+    view_to_editor (vs[i]) -> init_style ();
 }
 
 void
 tm_server_rep::refresh () {
-  path p= windows_list ();
-  while (!is_nil (p)) {
-    tm_view vw= window_find_view (p->item);
-    vw->win->refresh ();
-    p= p->next;
+  array<url> l= windows_list ();
+  for (int i=0; i<N(l); i++) {
+    url u= window_to_view (l[i]);
+    if (!is_none (u)) concrete_view (u)->win->refresh ();
   }
-  
 }
 
 void
@@ -205,7 +144,7 @@ tm_server_rep::interpose_handler () {
   exec_pending_commands ();
 #endif
 
-  int i,j;
+  int i, j;
   for (i=0; i<N(bufs); i++) {
     tm_buffer buf= (tm_buffer) bufs[i];
     for (j=0; j<N(buf->vws); j++) {
@@ -223,7 +162,7 @@ tm_server_rep::interpose_handler () {
 
 void
 tm_server_rep::wait_handler (string message, string arg) {
-  show_wait_indicator (get_window () -> win, translate (message), arg);
+  show_wait_indicator (concrete_window () -> win, translate (message), arg);
 }
 
 void
@@ -231,22 +170,6 @@ tm_server_rep::set_script_status (int i) {
   script_status= i;
 }
 
-void
-tm_server_rep::focus_on_editor (editor ed) {
-  int i,j;
-  for (i=0; i<N(bufs); i++) {
-    tm_buffer buf= (tm_buffer) bufs[i];
-    for (j=0; j<N(buf->vws); j++) {
-      tm_view vw= (tm_view) buf->vws[j];
-      if (vw->ed == ed) {
-	set_view (vw);
-	return;
-      }
-    }
-  }
-  FAILED ("invalid situation");
-}
-
 void
 tm_server_rep::set_printing_command (string cmd) {
   printing_cmd= cmd;
@@ -292,22 +215,16 @@ tm_server_rep::inclusions_gc (string which) {
 
 void
 tm_server_rep::typeset_update (path p) {
-  int i, j, n= N(bufs);
-  for (i=0; i<n; i++) {
-    tm_buffer buf= ((tm_buffer) bufs[i]);
-    for (j=0; j<N(buf->vws); j++)
-      ((tm_view) (buf->vws[j]))->ed->typeset_invalidate (p);
-  }
+  array<url> vs= get_all_views ();
+  for (int i=0; i<N(vs); i++)
+    view_to_editor (vs[i]) -> typeset_invalidate (p);
 }
 
 void
 tm_server_rep::typeset_update_all () {
-  int i, j, n= N(bufs);
-  for (i=0; i<n; i++) {
-    tm_buffer buf= ((tm_buffer) bufs[i]);
-    for (j=0; j<N(buf->vws); j++)
-      ((tm_view) (buf->vws[j]))->ed->typeset_invalidate_all ();
-  }
+  array<url> vs= get_all_views ();
+  for (int i=0; i<N(vs); i++)
+    view_to_editor (vs[i]) -> typeset_invalidate_all ();
 }
 
 bool
