@@ -10,6 +10,7 @@
 ******************************************************************************/
 
 #include "tm_window.hpp"
+#include "tm_data.hpp"
 #include "message.hpp"
 #include "dictionary.hpp"
 #include "merge_sort.hpp"
@@ -40,7 +41,7 @@ tm_window_rep::tm_window_rep (widget wid2, tree geom):
 
 tm_window_rep::tm_window_rep (tree doc, command quit):
   win (texmacs_widget (0, quit)),
-  wid (win), id (-1),
+  wid (win), id (url_none ()),
   serial (tm_window_serial++),
   menu_current (object ()), menu_cache (widget ()),
   text_ptr (NULL)
@@ -49,7 +50,7 @@ tm_window_rep::tm_window_rep (tree doc, command quit):
 }
 
 tm_window_rep::~tm_window_rep () {
-  if (id != -1) destroy_window_id (id);
+  if (!is_none (id)) destroy_window_id (id);
 }
 
 /******************************************************************************
@@ -91,11 +92,12 @@ public:
 void
 close_embedded_command_rep::apply () {
   //cout << "Destroy " << vw->buf->buf->name << "\n";
-  window_focus (vw->ed->mvw->win->id);
+  window_focus (abstract_window (vw->ed->mvw->win));
   //cout << "Changed focus\n";
   tm_window win= vw->win;
-  ASSERT (N(vw->buf->vws) == 1, "invalid cloned embedded TeXmacs widget");
-  delete_buffer (vw->buf);
+  ASSERT (N (buffer_to_views (vw->buf->buf->name)) == 1,
+          "invalid cloned embedded TeXmacs widget");
+  remove_buffer (vw->buf->buf->name);
   //cout << "Deleted buffer\n";
   tm_delete (win);
   //cout << "Deleted window\n";
@@ -110,11 +112,11 @@ close_embedded_command (tm_view vw) {
 * Embedded TeXmacs widgets
 ******************************************************************************/
 
-string
+url
 embedded_name () {
   static int nr= 0;
   nr++;
-  return "* Embedded " * as_string (nr) * " *";
+  return url (string ("tmfs://aux/TeXmacs-input-" * as_string (nr)));
 }
 
 tree
@@ -145,14 +147,13 @@ widget
 texmacs_input_widget (tree doc, command cmd, bool continuous) {
   (void) cmd; (void) continuous;
   doc= enrich_embedded_document (doc);
-  tm_view   curvw=  get_server () -> get_view ();
-  string    name = embedded_name ();
-  tm_buffer buf  = create_buffer (url (name), doc);
-  tm_view   vw   = get_passive_view (buf);
+  url       base = get_master_buffer (get_current_buffer ());
+  tm_view   curvw= concrete_view (get_current_view ());
+  url       name = embedded_name (); create_buffer (name, doc);
+  tm_view   vw   = concrete_view (get_passive_view (name));
   tm_window win  = tm_new<tm_window_rep> (doc, command ());
-  set_aux (name, name);
+  set_master_buffer (name, base);
   vw->win= win;
-  vw->buf->buf->in_menu= false;
   set_scrollable (win->wid, vw->ed);
   vw->ed->cvw= win->wid.rep;
   vw->ed->mvw= curvw;
