@@ -14,30 +14,19 @@
 #include "editor.hpp"
 #include "url.hpp"
 #include "scheme.hpp"
+#include "new_data.hpp"
+#include "Data/new_buffer.hpp"
+#include "Data/new_view.hpp"
+#include "Data/new_window.hpp"
+#include "Data/new_project.hpp"
 
-class tm_buffer_rep;
-class tm_view_rep;
-class tm_window_rep;
-typedef tm_buffer_rep* tm_buffer;
-typedef tm_view_rep*   tm_view;
-typedef tm_window_rep* tm_window;
 class editor;
 
 class server_rep: public abstract_struct {
 public:
   server_rep ();
   virtual ~server_rep ();
-
-  /* Get and set objects associated to server */
   virtual server_rep* get_server () = 0;
-  virtual bool        has_view () = 0;
-  virtual bool        has_window () = 0;
-  virtual tm_view     get_view (bool must_be_valid= true) = 0;
-  virtual void        set_view (tm_view vw) = 0;
-  virtual tm_buffer   get_buffer () = 0;
-  virtual editor      get_editor () = 0;
-  virtual tm_window   get_window () = 0;
-  virtual int         get_nr_windows () = 0;
 
   /* Control global server parameters */
   virtual void   set_font_rules (scheme_tree rules) = 0;
@@ -52,7 +41,7 @@ public:
 			      command& cmd, string& sh, string& help) = 0;
 
   /* TeXmacs frames */
-  virtual int  get_window_id () = 0;
+  virtual int  get_window_serial () = 0;
   virtual void set_window_property (scheme_tree what, scheme_tree val) = 0;
   virtual void set_bool_window_property (string what, bool val) = 0;
   virtual void set_int_window_property (string what, int val) = 0;
@@ -103,7 +92,6 @@ public:
   virtual void   interpose_handler () = 0;
   virtual void   wait_handler (string message, string arg) = 0;
   virtual void   set_script_status (int i) = 0;
-  virtual void   focus_on_editor (editor ed) = 0;
   virtual void   set_printing_command (string s) = 0;
   virtual void   set_printer_page_type (string s) = 0;
   virtual string get_printer_page_type () = 0;
@@ -129,81 +117,10 @@ extern bool rescue_mode;
 scheme_tree menu_merge (scheme_tree m1, scheme_tree m2);
 server get_server ();
 void gui_set_output_language (string lan);
+inline bool in_rescue_mode () { return rescue_mode; }
 
 /* low level */
-tm_buffer create_buffer (url name);
-tm_buffer create_buffer (url name, tree doc);
-int find_buffer (path p);
-int find_buffer (url name);
-void attach_view (tm_window win, tm_view vw);
-void detach_view (tm_view vw);
-tm_view get_passive_view (tm_buffer buf);
-void delete_buffer (tm_buffer buf);
-void delete_view (tm_view vw);
+void create_buffer (url name, tree doc);
 void new_buffer_in_this_window (url name, tree t);
-tm_window new_window (bool map_flag= true, tree geom= "");
-tm_buffer load_passive_buffer (url name);
-tree make_document (tm_view vw, string fm= "texmacs");
-
-/* Buffer management */
-url  get_all_buffers ();
-bool buffer_in_menu (url name);
-url  get_this_buffer ();
-void set_name_buffer (url name);
-url  get_name_buffer ();
-url  get_name_buffer (path p);
-void set_abbr_buffer (url name, string abbr);
-string get_abbr_buffer (url name);
-void revert_buffer (url name, tree doc);
-void new_buffer_in_new_window (url name, tree t, tree geom= "");
-double last_visited (url name);
-bool buffer_modified (url name);
-
-/* Buffer management */
-int  nr_bufs ();
-url  create_buffer ();
-void switch_to_buffer (int nr);
-bool switch_to_buffer (path p);
-void switch_to_buffer (url name);
-void switch_to_active_buffer (url name);
-void revert_buffer ();
-void kill_buffer ();
-url  open_window (tree geom= "");
-void clone_window ();
-void kill_window ();
-void kill_window_and_buffer ();
-bool no_bufs ();
-bool no_name ();
-bool help_buffer ();
-bool is_aux_buffer (url name);
-void set_aux (string aux, url name);
-void set_aux_buffer (string aux, url name, tree doc);
-void set_help_buffer (url name, tree doc);
-void browse_help (int delta);
-void set_buffer_tree (url name, tree doc);
-tree get_buffer_tree (url name);
-
-/* Project management */
-void project_attach (string prj_name= "");
-bool project_attached ();
-url  project_get ();
-
-/* Window management */
-int  window_current ();
-path windows_list ();
-path buffer_to_windows (url name);
-url  window_to_buffer (int id);
-tm_view window_find_view (int id);
-void window_set_buffer (int id, url name);
-void window_focus (int id);
-
-/* File management */
-tree load_tree (url name, string fm);
-void load_buffer (url name, string fm, int where= 0, bool asf= false);
-void save_buffer (url name, string fm);
-void auto_save ();
-bool buffer_unsaved ();
-bool exists_unsaved_buffer ();
-void pretend_save_buffer ();
 
 #endif // defined SERVER_H
