@@ -22,23 +22,12 @@ class tm_server_rep:
   public tm_frame_rep
 {
 protected:
-  tm_view vw;             // current editor
-  int def_sfactor;        // default shrinking factor
+  int def_sfactor; // default shrinking factor
 
 public:
   tm_server_rep ();
   ~tm_server_rep ();
-
-  /* Get and set objects associated to server */
   server_rep* get_server ();
-  bool        has_view ();
-  bool        has_window ();
-  tm_view     get_view (bool must_be_valid= true);
-  void        set_view (tm_view vw);
-  tm_buffer   get_buffer ();
-  editor      get_editor ();
-  tm_window   get_window ();
-  int         get_nr_windows ();
 
   /* Miscellaneous routines */
   void   style_clear_cache ();
@@ -46,7 +35,6 @@ public:
   void   interpose_handler ();
   void   wait_handler (string message, string arg);
   void   set_script_status (int i);
-  void   focus_on_editor (editor ed);
   void   set_printing_command (string s);
   void   set_printer_page_type (string s);
   string get_printer_page_type ();
