@@ -4,16 +4,14 @@
 * DESCRIPTION: Important routines for all boxes
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "boxes.hpp"
 #include "formatter.hpp"
 #include "Graphics/point.hpp"
-#include "timer.hpp"
 #include "printer.hpp"
 #include "file.hpp"
 #include "merge_sort.hpp"
@@ -296,11 +294,12 @@ box_rep::find_frame (path bp, bool last) {
     b  = b->subbox (bp->item);
     bp = bp->next;
     frame g= b->get_frame ();
-    if (!is_nil (g))
+    if (!is_nil (g)) {
       if (last)
 	f= g;
       else
 	f= scaling (1.0, point (x, y)) * g;
+    }
   }
   return f;
 }
@@ -351,6 +350,7 @@ box_rep::graphical_select (SI x, SI y, SI dist) {
   gr_selections res;
   if (graphical_distance (x, y) <= dist) {
     gr_selection gs;
+    gs->type= "box";
     gs->dist= graphical_distance (x, y);
     gs->cp << find_tree_path (x, y, dist);
     // FIXME: check whether this is correct: I do not remember whether
@@ -366,6 +366,7 @@ box_rep::graphical_select (SI x1, SI y1, SI x2, SI y2) {
   gr_selections res;
   if (in_rectangle (x1, y1, x2, y2)) {
     gr_selection gs;
+    gs->type= "box";
     gs->dist= graphical_distance (x1, y1);
     SI dist= (SI)norm (point (x2-x1, y2-y1));
     gs->cp << find_tree_path (x1, y1, dist);
@@ -395,57 +396,57 @@ box_rep::get_info (tree in) {
 int
 box_rep::get_leaf_left_pos () {
   cerr << "\nTeXmacs] the box is " << box (this) << "\n";
-  fatal_error ("this box is not textual", "get_leaf_left_pos");
-  return 0; // Because of bug in certain versions of g++
+  FAILED ("this box is not textual");
+  return 0;
 }
 
 int
 box_rep::get_leaf_right_pos () {
   cerr << "\nTeXmacs] the box is " << box (this) << "\n";
-  fatal_error ("this box is not textual", "get_leaf_right_pos");
-  return 0; // Because of bug in certain versions of g++
+  FAILED ("this box is not textual");
+  return 0;
 }
 
 string
 box_rep::get_leaf_string () {
   cerr << "\nTeXmacs] the box is " << box (this) << "\n";
-  fatal_error ("this box is not textual", "get_leaf_string");
-  return ""; // Because of bug in certain versions of g++
+  FAILED ("this box is not textual");
+  return "";
 }
 
 font
 box_rep::get_leaf_font () {
   cerr << "\nTeXmacs] the box is " << box (this) << "\n";
-  fatal_error ("this box is not textual", "get_leaf_font");
-  return font (); // Because of bug in certain versions of g++
+  FAILED ("this box is not textual");
+  return font ();
 }
 
 color
 box_rep::get_leaf_color () {
   cerr << "\nTeXmacs] the box is " << box (this) << "\n";
-  fatal_error ("this box is not textual", "get_leaf_color");
-  return 0; // Because of bug in certain versions of g++
+  FAILED ("this box is not textual");
+  return 0;
 }
 
 language
 box_rep::get_leaf_language () {
   cerr << "\nTeXmacs] the box is " << box (this) << "\n";
-  fatal_error ("this box is not textual", "get_leaf_language");
-  return language (); // Because of bug in certain versions of g++
+  FAILED ("this box is not textual");
+  return language ();
 }
 
 tree
 box_rep::get_leaf_tree () {
   cerr << "\nTeXmacs] the box is " << box (this) << "\n";
-  fatal_error ("no tree attached to this box", "get_leaf_tree");
-  return ""; // Because of bug in certain versions of g++
+  FAILED ("no tree attached to this box");
+  return "";
 }
 
 lazy
 box_rep::get_leaf_lazy () {
   cerr << "\nTeXmacs] the box is " << box (this) << "\n";
-  fatal_error ("no lazy attached to this box", "get_leaf_lazy");
-  return lazy (); // Because of bug in certain versions of g++
+  FAILED ("no lazy attached to this box");
+  return lazy ();
 }
 
 SI
@@ -556,7 +557,7 @@ box_rep::post_display (renderer &ren) {
 ******************************************************************************/
 
 cursor::cursor (SI x, SI y, SI delta, SI y1, SI y2, double slope, bool valid):
-  rep (new cursor_rep)
+  rep (tm_new<cursor_rep> ())
 {
   rep->ox= x ; rep->oy= y ; rep->delta= delta;
   rep->y1= y1; rep->y2= y2; rep->slope= slope;
@@ -583,8 +584,8 @@ operator != (cursor cu1, cursor cu2) {
   return ! (cu1 == cu2);
 }
 
-ostream&
-operator << (ostream& out, cursor cu) {
+tm_ostream&
+operator << (tm_ostream& out, cursor cu) {
   out << "cursor (" << (cu->ox>>8) << ", " << (cu->oy>>8) << ": "
       << cu->delta << ": "
       << (cu->y1>>8) << ", " << (cu->y2>>8) << ": "
@@ -597,7 +598,7 @@ operator << (ostream& out, cursor cu) {
 ******************************************************************************/
 
 selection::selection (rectangles rs, path start, path end, bool valid):
-  rep (new selection_rep)
+  rep (tm_new<selection_rep> ())
 {
   rep->rs   = rs;
   rep->start= start;
@@ -617,8 +618,8 @@ operator != (selection sel1, selection sel2) {
   return !(sel1 == sel2);
 }
 
-ostream&
-operator << (ostream& out, selection sel) {
+tm_ostream&
+operator << (tm_ostream& out, selection sel) {
   return out << "selection (" << sel->start << ", " << sel->end << ")";
 }
 
@@ -627,15 +628,16 @@ operator << (ostream& out, selection sel) {
 ******************************************************************************/
 
 gr_selection::gr_selection (array<path> cp, SI dist):
-  rep (new gr_selection_rep)
+  rep (tm_new<gr_selection_rep> ())
 {
   rep->cp  = cp;
   rep->dist= dist;
 }
 
-ostream&
-operator << (ostream& out, gr_selection sel) {
-  return out << "gr_selection (" << sel->dist << ", " << sel->cp << ")";
+tm_ostream&
+operator << (tm_ostream& out, gr_selection sel) {
+  return out << "gr_selection (" << sel->type << ", "
+	     << sel->dist << ", " << sel->cp << ")";
 }
 
 struct less_eq_gr_selection {
@@ -643,8 +645,14 @@ struct less_eq_gr_selection {
     return a->dist <= b->dist; }
 };
 
-tree as_tree (gr_selections sels) {
+void
+sort (gr_selections& sels) {
   merge_sort_leq <gr_selection, less_eq_gr_selection> (sels);
+}
+
+tree
+as_tree (gr_selections sels) {
+  sort (sels);
   int i, n= N(sels);
   array<array<path> > res (n);
   for (i=0; i<n; i++)
@@ -652,6 +660,7 @@ tree as_tree (gr_selections sels) {
   return (tree) res;
 }
 
+
 /******************************************************************************
 * Animations
 ******************************************************************************/
@@ -699,7 +708,7 @@ box_rep::anim_finish_now () {
 
 time_t
 box_rep::anim_next_update () {
-  fatal_error ("Invalid situation", "box_rep::anim_next_update");
+  FAILED ("invalid situation");
   return texmacs_time ();
 }
 
@@ -778,7 +787,7 @@ bool box::operator == (box b2) { return rep==b2.rep; }
 bool box::operator != (box b2) { return rep!=b2.rep; }
 
 box::operator tree () { return tree (*rep); }
-ostream& operator << (ostream& out, box b) { return out << ((tree) b); }
+tm_ostream& operator << (tm_ostream& out, box b) { return out << ((tree) b); }
 
 path
 descend_decode (path ip, int side) {
@@ -828,5 +837,5 @@ make_eps (url name, box b, int dpi) {
   ren->set_background (white);
   rectangles rs;
   b->redraw (ren, path (0), rs);
-  delete ren;
+  tm_delete (ren);
 }
