@@ -71,6 +71,7 @@ class concater_rep {
   //void typeset_middle (tree t, path ip);
   //void typeset_right (tree t, path ip);
   void typeset_bigop (tree t, path ip);
+  void typeset_long_arrow (tree t, path ip);
   void typeset_lprime (tree t, path ip);
   void typeset_rprime (tree t, path ip);
   void typeset_below (tree t, path ip);
@@ -132,12 +133,15 @@ class concater_rep {
   void typeset_sound (tree t, path ip);
 
   // graphical markup
+  void typeset_graphical (array<box>& bs, tree t, path ip);
   void typeset_graphics (tree t, path ip);
   void typeset_superpose (tree t, path ip);
   void typeset_gr_group (tree t, path ip);
   void typeset_gr_linear_transform (tree t, path ip);
   void typeset_text_at (tree t, path ip);
+  void typeset_math_at (tree t, path ip);
   void typeset_point (tree t, path ip);
+  array<box> typeset_line_arrows (path ip);
   void typeset_line (tree t, path ip, bool close);
   void typeset_arc (tree t, path ip, bool close);
   void typeset_spline (tree t, path ip, bool close);
